@@ -23,8 +23,7 @@
 #include "kopeterichtextwidget.h"
 
 // KDE includes
-#include <kdebug.h>
-#include <kaction.h>
+#include "kopetechatwindow_debug.h"
 #include <kactioncollection.h>
 #include <kactionmenu.h>
 #include <klocalizedstring.h>
@@ -33,12 +32,15 @@
 #include <KConfigGroup>
 
 // Qt includes
+#include <QMimeData>
 #include <QUrl>
-#include <QtCore/QEvent>
+#include <QEvent>
+#include <QAction>
 #include <QKeyEvent>
-#include <QtGui/QTextCursor>
-#include <QtGui/QTextCharFormat>
+#include <QTextCursor>
+#include <QTextCharFormat>
 #include <QTextDocumentFragment>
+#include <KSharedConfig>
 
 // TODO: Add i18n context
 
@@ -51,8 +53,16 @@ class KopeteRichTextWidget::Private
 {
 public:
     Private(KopeteRichTextWidget *parent, KActionCollection *ac, Kopete::Protocol::Capabilities caps)
-        : q(parent), actionCollection(ac), protocolCaps(caps), resettingCharFormat(false), empty(true), updating(false), changingTextMode(false),
-        checkSpelling(0), toggleRichText(0), reset(0)
+        : q(parent)
+        , actionCollection(ac)
+        , protocolCaps(caps)
+        , resettingCharFormat(false)
+        , empty(true)
+        , updating(false)
+        , changingTextMode(false)
+        , checkSpelling(0)
+        , toggleRichText(0)
+        , reset(0)
     {
     }
 
@@ -75,18 +85,18 @@ public:
 
     bool changingTextMode;
 
-    KToggleAction* autoResize;
-    KToggleAction* checkSpelling;
-    KToggleAction* toggleRichText;
-    KAction* reset;
+    KToggleAction *autoResize;
+    KToggleAction *checkSpelling;
+    KToggleAction *toggleRichText;
+    QAction *reset;
 
-    void mergeAll(const QTextCharFormat& format);
+    void mergeAll(const QTextCharFormat &format);
 };
 //@endcond
 
-KopeteRichTextWidget::KopeteRichTextWidget(QWidget* parent, Kopete::Protocol::Capabilities protocolCaps, KActionCollection *actionCollection)
-        : KRichTextWidget(parent),
-        d(new Private(this, actionCollection, protocolCaps))
+KopeteRichTextWidget::KopeteRichTextWidget(QWidget *parent, Kopete::Protocol::Capabilities protocolCaps, KActionCollection *actionCollection)
+    : KRichTextWidget(parent)
+    , d(new Private(this, actionCollection, protocolCaps))
 {
     connect(this, SIGNAL(textModeChanged(KRichTextEdit::Mode)),
             this, SLOT(slotTextModeChanged(KRichTextEdit::Mode)));
@@ -108,28 +118,24 @@ KopeteRichTextWidget::KopeteRichTextWidget(QWidget* parent, Kopete::Protocol::Ca
 
 KopeteRichTextWidget::~KopeteRichTextWidget()
 {
-    KConfigGroup configGroupMode( KGlobal::config(), QLatin1String( "KopeteChatWindowGroupMode" ));
-    KConfigGroup configIndividual( KGlobal::config(), QLatin1String( "KopeteChatWindowIndividualMode" ));
-    configGroupMode.writeEntry( "AutoResize", d->autoResize->isChecked());
-    configIndividual.writeEntry( "AutoResize", d->autoResize->isChecked());
+    KConfigGroup configGroupMode(KSharedConfig::openConfig(), QStringLiteral("KopeteChatWindowGroupMode"));
+    KConfigGroup configIndividual(KSharedConfig::openConfig(), QStringLiteral("KopeteChatWindowIndividualMode"));
+    configGroupMode.writeEntry("AutoResize", d->autoResize->isChecked());
+    configIndividual.writeEntry("AutoResize", d->autoResize->isChecked());
     delete d;
 }
 
 void KopeteRichTextWidget::setTextOrHtml(const QString &text)
 {
-    if (Qt::mightBeRichText(text))
-    {
-        if (isRichTextEnabled())
+    if (Qt::mightBeRichText(text)) {
+        if (isRichTextEnabled()) {
             setHtml(text);
-        else
-        {
+        } else {
             QTextDocument doc;
             doc.setHtml(text);
             setPlainText(doc.toPlainText());
         }
-    }
-    else
-    {
+    } else {
         setPlainText(text);
     }
 }
@@ -148,63 +154,53 @@ void KopeteRichTextWidget::slotDocumentSizeUpdated()
 
 void KopeteRichTextWidget::slotEnableAutoResize(bool enable)
 {
-    if (enable)
-    {
+    if (enable) {
         connect(this, SIGNAL(textChanged()),
                 this, SLOT(slotDocumentSizeUpdated()));
-    }
-    else
-    {
+    } else {
         disconnect(this, SLOT(slotDocumentSizeUpdated()));
     }
 }
 
 void KopeteRichTextWidget::createActions(KActionCollection *actionCollection)
 {
-    KConfigGroup config(KGlobal::config(), QLatin1String("KopeteChatWindowIndividualMode"));
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("KopeteChatWindowIndividualMode"));
 
     bool autoResizeEnabled = config.readEntry("AutoResize", true);
-    d->autoResize = new KToggleAction( i18n("Input auto-resize"), actionCollection );
-    connect( d->autoResize, SIGNAL(toggled(bool)), this, SLOT(slotEnableAutoResize(bool)) );
+    d->autoResize = new KToggleAction(i18n("Input auto-resize"), actionCollection);
+    connect(d->autoResize, SIGNAL(toggled(bool)), this, SLOT(slotEnableAutoResize(bool)));
     d->autoResize->setChecked(autoResizeEnabled);
     slotEnableAutoResize(autoResizeEnabled);
-    actionCollection->addAction( "enable_autoresize", d->autoResize );
+    actionCollection->addAction(QStringLiteral("enable_autoresize"), d->autoResize);
 
-    if (!d->checkSpelling)
-    {
-        d->checkSpelling = new KToggleAction(KIcon("tools-check-spelling"), i18n("Automatic Spell Checking"), actionCollection);
-        actionCollection->addAction("enable_auto_spell_check", d->checkSpelling);
+    if (!d->checkSpelling) {
+        d->checkSpelling = new KToggleAction(QIcon::fromTheme(QStringLiteral("tools-check-spelling")), i18n("Automatic Spell Checking"), actionCollection);
+        actionCollection->addAction(QStringLiteral("enable_auto_spell_check"), d->checkSpelling);
         d->checkSpelling->setChecked(true);
         connect(d->checkSpelling, SIGNAL(toggled(bool)), this, SLOT(slotCheckSpellingChanged(bool)));
     }
 
     bool richTextSupport = (getProtocolRichTextSupport() != KopeteRichTextWidget::DisableRichText);
-    if (!d->toggleRichText && richTextSupport)
-    {
-        d->toggleRichText = new KToggleAction(KIcon("draw-freehand"), i18n("Enable &Rich Text"), actionCollection);
-        actionCollection->addAction("enable_richtext", d->toggleRichText);
+    if (!d->toggleRichText && richTextSupport) {
+        d->toggleRichText = new KToggleAction(QIcon::fromTheme(QStringLiteral("draw-freehand")), i18n("Enable &Rich Text"), actionCollection);
+        actionCollection->addAction(QStringLiteral("enable_richtext"), d->toggleRichText);
         d->toggleRichText->setChecked(isRichTextEnabled());
         connect(d->toggleRichText, SIGNAL(toggled(bool)), this, SLOT(setRichTextEnabled(bool)));
-    }
-    else if (d->toggleRichText && !richTextSupport)
-    {
+    } else if (d->toggleRichText && !richTextSupport) {
         actionCollection->removeAction(d->toggleRichText);
         d->toggleRichText = 0;
     }
 
-    if (!d->reset && isRichTextEnabled())
-    {
-        d->reset = new KAction(KIcon("format-stroke-color"), i18n("Reset Font And Color"), actionCollection);
-        actionCollection->addAction("format_font_and_color_reset", d->reset);
+    if (!d->reset && isRichTextEnabled()) {
+        d->reset = new QAction(QIcon::fromTheme(QStringLiteral("format-stroke-color")), i18n("Reset Font And Color"), actionCollection);
+        actionCollection->addAction(QStringLiteral("format_font_and_color_reset"), d->reset);
         connect(d->reset, SIGNAL(triggered(bool)), this, SLOT(slotResetFontAndColor()));
-    }
-    else if (d->reset && !isRichTextEnabled())
-    {
+    } else if (d->reset && !isRichTextEnabled()) {
         actionCollection->removeAction(d->reset);
         d->reset = 0;
     }
 
-    KRichTextWidget::createActions(actionCollection);
+    actionCollection->addActions(KRichTextWidget::createActions());
 
     // FIXME: Really ugly hack, but we reset format in updateCharFormat and if we don't disconnect this
     //        then actions will have old values and not the reset.
@@ -214,21 +210,19 @@ void KopeteRichTextWidget::createActions(KActionCollection *actionCollection)
 
 void KopeteRichTextWidget::setRichTextEnabled(bool enable)
 {
-    if (isRichTextEnabled() == enable)
+    if (isRichTextEnabled() == enable) {
         return;
+    }
 
     KopeteRichTextWidget::RichTextSupport richText = getProtocolRichTextSupport();
-    if (enable && richText != KopeteRichTextWidget::DisableRichText)
-    {
+    if (enable && richText != KopeteRichTextWidget::DisableRichText) {
         setRichTextSupport(richText);
         d->changingTextMode = true;
         enableRichTextMode();
         d->changingTextMode = false;
         createActions(d->actionCollection);
         setCurrentRichCharFormat(d->currentRichFormat);
-    }
-    else
-    {
+    } else {
         setRichTextSupport(KopeteRichTextWidget::DisableRichText);
         d->changingTextMode = true;
         switchToPlainText();
@@ -237,11 +231,13 @@ void KopeteRichTextWidget::setRichTextEnabled(bool enable)
         setCurrentPlainCharFormat(d->defaultPlainFormat);
     }
 
-    if (d->toggleRichText)
+    if (d->toggleRichText) {
         d->toggleRichText->setChecked(isRichTextEnabled());
+    }
 
-    if (d->reset)
+    if (d->reset) {
         d->reset->setEnabled(isRichTextEnabled());
+    }
 
     emit richTextSupportChanged();
 }
@@ -254,17 +250,15 @@ void KopeteRichTextWidget::slotResetFontAndColor()
 void KopeteRichTextWidget::setFontFamily(QString family)
 {
     d->currentRichFormat.setFontFamily(family);
-    if (!isRichTextEnabled())
+    if (!isRichTextEnabled()) {
         return;
+    }
 
-    if (d->protocolCaps & Kopete::Protocol::BaseFont)
-    {
+    if (d->protocolCaps & Kopete::Protocol::BaseFont) {
         QTextCharFormat format;
         format.setFontFamily(family);
         d->mergeAll(format);
-    }
-    else
-    {
+    } else {
         KRichTextWidget::setFontFamily(family);
     }
 }
@@ -272,17 +266,15 @@ void KopeteRichTextWidget::setFontFamily(QString family)
 void KopeteRichTextWidget::setFontSize(int size)
 {
     d->currentRichFormat.setFontPointSize(size);
-    if (!isRichTextEnabled())
+    if (!isRichTextEnabled()) {
         return;
+    }
 
-    if (d->protocolCaps & Kopete::Protocol::BaseFont)
-    {
+    if (d->protocolCaps & Kopete::Protocol::BaseFont) {
         QTextCharFormat format;
         format.setFontPointSize(size);
         d->mergeAll(format);
-    }
-    else
-    {
+    } else {
         KRichTextWidget::setFontSize(size);
     }
 }
@@ -293,17 +285,15 @@ void KopeteRichTextWidget::setTextBold(bool bold)
     font.setBold(bold);
     d->currentRichFormat.setFont(font);
 
-    if (!isRichTextEnabled())
+    if (!isRichTextEnabled()) {
         return;
+    }
 
-    if (d->protocolCaps & Kopete::Protocol::BaseBFormatting)
-    {
+    if (d->protocolCaps & Kopete::Protocol::BaseBFormatting) {
         QTextCharFormat format;
         format.setFontWeight(d->currentRichFormat.fontWeight());
         d->mergeAll(format);
-    }
-    else
-    {
+    } else {
         KRichTextWidget::setTextBold(bold);
     }
 }
@@ -311,17 +301,15 @@ void KopeteRichTextWidget::setTextBold(bool bold)
 void KopeteRichTextWidget::setTextItalic(bool italic)
 {
     d->currentRichFormat.setFontItalic(italic);
-    if (!isRichTextEnabled())
+    if (!isRichTextEnabled()) {
         return;
+    }
 
-    if (d->protocolCaps & Kopete::Protocol::BaseIFormatting)
-    {
+    if (d->protocolCaps & Kopete::Protocol::BaseIFormatting) {
         QTextCharFormat format;
         format.setFontItalic(italic);
         d->mergeAll(format);
-    }
-    else
-    {
+    } else {
         KRichTextWidget::setTextItalic(italic);
     }
 }
@@ -329,71 +317,66 @@ void KopeteRichTextWidget::setTextItalic(bool italic)
 void KopeteRichTextWidget::setTextUnderline(bool underline)
 {
     d->currentRichFormat.setFontUnderline(underline);
-    if (!isRichTextEnabled())
+    if (!isRichTextEnabled()) {
         return;
+    }
 
-    if (d->protocolCaps & Kopete::Protocol::BaseUFormatting)
-    {
+    if (d->protocolCaps & Kopete::Protocol::BaseUFormatting) {
         QTextCharFormat format;
         format.setFontItalic(underline);
         d->mergeAll(format);
-    }
-    else
-    {
+    } else {
         KRichTextWidget::setTextUnderline(underline);
     }
 }
 
 void KopeteRichTextWidget::setTextStrikeOut(bool)
 {
-    kDebug() << "Strikeout not supported!";
+    qDebug() << "Strikeout not supported!";
 }
 
-void KopeteRichTextWidget::setCurrentCharFormat(const QTextCharFormat & format)
+void KopeteRichTextWidget::setCurrentCharFormat(const QTextCharFormat &format)
 {
     d->lastCharFormat = format;
     KRichTextWidget::setCurrentCharFormat(format);
 }
 
-void KopeteRichTextWidget::updateCharFormat(const QTextCharFormat & f)
+void KopeteRichTextWidget::updateCharFormat(const QTextCharFormat &f)
 {
     // TODO: This should go to KRichTextWidget or KRichTextEdit
-    if (d->resettingCharFormat)
+    if (d->resettingCharFormat) {
         return;
+    }
 
-    if (f != QTextCharFormat() || !document()->isEmpty())
-    {
+    if (f != QTextCharFormat() || !document()->isEmpty()) {
         d->lastCharFormat = f;
         bool bOpaque = d->lastCharFormat.foreground().isOpaque();
         bool fOpaque = d->lastCharFormat.background().isOpaque();
 
-        if (!fOpaque)
+        if (!fOpaque) {
             d->lastCharFormat.setForeground(palette().color(QPalette::Active, QPalette::Text));
-        if (!bOpaque)
+        }
+        if (!bOpaque) {
             d->lastCharFormat.setBackground(palette().color(QPalette::Active, QPalette::Base));
+        }
 
-        if (!fOpaque || !bOpaque)
-        {
+        if (!fOpaque || !bOpaque) {
             d->resettingCharFormat = true;
             KRichTextWidget::setCurrentCharFormat(d->lastCharFormat);
             d->resettingCharFormat = false;
         }
 
-        if (isRichTextEnabled() && d->currentRichFormat != d->lastCharFormat)
-        {
+        if (isRichTextEnabled() && d->currentRichFormat != d->lastCharFormat) {
             d->currentRichFormat = d->lastCharFormat;
 
-            if (d->protocolCaps & Kopete::Protocol::BaseBgColor)
-            {
+            if (d->protocolCaps & Kopete::Protocol::BaseBgColor) {
                 QPalette palette = this->palette();
                 palette.setColor(QPalette::Active, QPalette::Base, d->lastCharFormat.background().color());
                 palette.setColor(QPalette::Inactive, QPalette::Base, d->lastCharFormat.background().color());
                 this->setPalette(palette);
             }
         }
-    }
-    else
-    {
+    } else {
         d->resettingCharFormat = true;
         KRichTextWidget::setCurrentCharFormat(d->lastCharFormat);
         d->resettingCharFormat = false;
@@ -403,12 +386,12 @@ void KopeteRichTextWidget::updateCharFormat(const QTextCharFormat & f)
 
 void KopeteRichTextWidget::updateTextFormat()
 {
-    if (d->updating || !isRichTextEnabled())
+    if (d->updating || !isRichTextEnabled()) {
         return;
+    }
 
     bool empty = document()->isEmpty();
-    if (!empty && d->empty)
-    {
+    if (!empty && d->empty) {
         d->updating = true;
         QTextCursor cursor = textCursor();
         cursor.beginEditBlock();
@@ -422,25 +405,21 @@ void KopeteRichTextWidget::updateTextFormat()
     d->empty = empty;
 }
 
-void KopeteRichTextWidget::insertFromMimeData(const QMimeData * source)
+void KopeteRichTextWidget::insertFromMimeData(const QMimeData *source)
 {
-    if (source->hasUrls())
-    {
+    if (source->hasUrls()) {
         QList<QUrl> urls = source->urls();
-        if (urls.size() > 0)
-        {
+        if (urls.size() > 0) {
             textCursor().insertText(urls[0].toString());
             return;
         }
     }
 
     // If HTML then you need to unset d->empty to make sure rich text gets through correctly
-    if (source->hasHtml())
-    {
+    if (source->hasHtml()) {
         d->empty = d->empty && source->html().isEmpty();
         // double check to make sure we aren't pasting empty space
-        if (d->empty)
-        {
+        if (d->empty) {
             QTextDocumentFragment frag = QTextDocumentFragment::fromHtml(source->html());
             d->empty = frag.toPlainText().trimmed().isEmpty();
         }
@@ -451,13 +430,10 @@ void KopeteRichTextWidget::insertFromMimeData(const QMimeData * source)
 
 bool KopeteRichTextWidget::event(QEvent *event)
 {
-    if (event->type() == QEvent::ShortcutOverride)
-    {
-        QKeyEvent *keyEvent = dynamic_cast<QKeyEvent*>(event);
-        if (keyEvent)
-        {
-            if (keyEvent->matches(QKeySequence::Copy) && !textCursor().hasSelection())
-            {
+    if (event->type() == QEvent::ShortcutOverride) {
+        QKeyEvent *keyEvent = dynamic_cast<QKeyEvent *>(event);
+        if (keyEvent) {
+            if (keyEvent->matches(QKeySequence::Copy) && !textCursor().hasSelection()) {
                 // The copy shortcut has to be handled outside of
                 // the textedit because otherwise you cannot use it
                 // to copy a selection in the chatmessagepart
@@ -465,23 +441,19 @@ bool KopeteRichTextWidget::event(QEvent *event)
                 return QWidget::event(event);
             }
             if ((keyEvent->matches(QKeySequence::MoveToPreviousPage) || keyEvent->matches(QKeySequence::MoveToNextPage))
-                && document()->isEmpty())
-            {
+                && document()->isEmpty()) {
                 // Allow to scroll the chat if the user has not entered
                 // some text in the KRichTextEditPart.
                 return QWidget::event(event);
             }
         }
     }
-    if (event->type() == QEvent::ShortcutOverride || event->type() == QEvent::KeyRelease || event->type() == QEvent::KeyPress){
-        QKeyEvent *keyEvent = dynamic_cast<QKeyEvent*>(event);
-        if (keyEvent)
-        {
+    if (event->type() == QEvent::ShortcutOverride || event->type() == QEvent::KeyRelease || event->type() == QEvent::KeyPress) {
+        QKeyEvent *keyEvent = dynamic_cast<QKeyEvent *>(event);
+        if (keyEvent) {
             QKeySequence keyEventSequance(keyEvent->modifiers() + keyEvent->key());
-            foreach(const QKeySequence& sendKeySequence, d->sendKeySequenceList)
-            {
-                if (keyEventSequance.matches(sendKeySequence))
-                {
+            foreach (const QKeySequence &sendKeySequence, d->sendKeySequenceList) {
+                if (keyEventSequance.matches(sendKeySequence)) {
                     // Don't handle the shortcut for sending text in the textedit
                     return false;// QWidget::event(event);
                 }
@@ -491,21 +463,22 @@ bool KopeteRichTextWidget::event(QEvent *event)
     return KRichTextWidget::event(event);
 }
 
-void KopeteRichTextWidget::setSendKeySequenceList(const QList<QKeySequence>& keySequenceList)
+void KopeteRichTextWidget::setSendKeySequenceList(const QList<QKeySequence> &keySequenceList)
 {
-        d->sendKeySequenceList = keySequenceList;
+    d->sendKeySequenceList = keySequenceList;
 }
 
-void KopeteRichTextWidget::setDefaultPlainCharFormat(const QTextCharFormat& format)
+void KopeteRichTextWidget::setDefaultPlainCharFormat(const QTextCharFormat &format)
 {
     d->defaultPlainFormat = format;
     setCurrentPlainCharFormat(d->defaultPlainFormat);
 }
 
-void KopeteRichTextWidget::setCurrentPlainCharFormat(const QTextCharFormat & format)
+void KopeteRichTextWidget::setCurrentPlainCharFormat(const QTextCharFormat &format)
 {
-    if (isRichTextEnabled())
+    if (isRichTextEnabled()) {
         return;
+    }
 
     setCurrentCharFormat(format);
     d->mergeAll(format);
@@ -517,32 +490,32 @@ void KopeteRichTextWidget::setCurrentPlainCharFormat(const QTextCharFormat & for
     this->setPalette(palette);
 }
 
-void KopeteRichTextWidget::setDefaultRichCharFormat(const QTextCharFormat& format)
+void KopeteRichTextWidget::setDefaultRichCharFormat(const QTextCharFormat &format)
 {
     bool usingDefaultFormat = (d->defaultRichFormat == d->currentRichFormat);
 
     d->defaultRichFormat = format;
-    if (usingDefaultFormat)
+    if (usingDefaultFormat) {
         setCurrentRichCharFormat(d->defaultRichFormat);
+    }
 }
 
-void KopeteRichTextWidget::setCurrentRichCharFormat(const QTextCharFormat & format)
+void KopeteRichTextWidget::setCurrentRichCharFormat(const QTextCharFormat &format)
 {
     d->currentRichFormat = format;
 
-    if (isRichTextEnabled())
-    {
+    if (isRichTextEnabled()) {
         setCurrentCharFormat(format);
-        if (d->protocolCaps & (Kopete::Protocol::BaseFormatting | Kopete::Protocol::BaseColor))
-        {
+        if (d->protocolCaps & (Kopete::Protocol::BaseFormatting | Kopete::Protocol::BaseColor)) {
             d->mergeAll(format);
         }
 
         QColor color;
-        if (d->protocolCaps & Kopete::Protocol::BaseBgColor)
+        if (d->protocolCaps & Kopete::Protocol::BaseBgColor) {
             color = format.background().color();
-        else
+        } else {
             color = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
+        }
 
         QPalette palette = this->palette();
         palette.setColor(QPalette::Active, QPalette::Base, color);
@@ -568,15 +541,14 @@ QTextCharFormat KopeteRichTextWidget::currentRichFormat() const
 
 bool KopeteRichTextWidget::isRichTextEnabled() const
 {
-    return (textMode() == KopeteRichTextWidget::Rich);
+    return textMode() == KopeteRichTextWidget::Rich;
 }
 
 void KopeteRichTextWidget::slotTextModeChanged(KRichTextEdit::Mode)
 {
-    if (d->changingTextMode == false)
-    {
-        kWarning() << "Unexpected text mode change!!!";
-        kWarning() << kBacktrace();
+    if (d->changingTextMode == false) {
+        qCWarning(KOPETE_CHATEWINDOW_LOG) << "Unexpected text mode change!!!";
+        //kWarning() << kBacktrace();
     }
 }
 
@@ -585,45 +557,38 @@ KopeteRichTextWidget::RichTextSupport KopeteRichTextWidget::getProtocolRichTextS
     KopeteRichTextWidget::RichTextSupport richText = KopeteRichTextWidget::DisableRichText;
 
     // Check for bold
-    if ((d->protocolCaps & Kopete::Protocol::BaseBFormatting) || (d->protocolCaps & Kopete::Protocol::RichBFormatting))
-    {
+    if ((d->protocolCaps & Kopete::Protocol::BaseBFormatting) || (d->protocolCaps & Kopete::Protocol::RichBFormatting)) {
         richText |= KopeteRichTextWidget::SupportBold;
     }
     // Check for italic
-    if ((d->protocolCaps & Kopete::Protocol::BaseIFormatting) || (d->protocolCaps & Kopete::Protocol::RichIFormatting))
-    {
+    if ((d->protocolCaps & Kopete::Protocol::BaseIFormatting) || (d->protocolCaps & Kopete::Protocol::RichIFormatting)) {
         richText |= KopeteRichTextWidget::SupportItalic;
     }
     // Check for underline
-    if ((d->protocolCaps & Kopete::Protocol::BaseUFormatting) || (d->protocolCaps & Kopete::Protocol::RichUFormatting))
-    {
+    if ((d->protocolCaps & Kopete::Protocol::BaseUFormatting) || (d->protocolCaps & Kopete::Protocol::RichUFormatting)) {
         richText |= KopeteRichTextWidget::SupportUnderline;
     }
     // Check for font support
-    if ((d->protocolCaps & Kopete::Protocol::BaseFont) || (d->protocolCaps & Kopete::Protocol::RichFont))
-    {
+    if ((d->protocolCaps & Kopete::Protocol::BaseFont) || (d->protocolCaps & Kopete::Protocol::RichFont)) {
         richText |= KopeteRichTextWidget::SupportFontFamily | KopeteRichTextWidget::SupportFontSize;
     }
     // Check for text color support
-    if ((d->protocolCaps & Kopete::Protocol::BaseFgColor) || (d->protocolCaps & Kopete::Protocol::RichFgColor))
-    {
+    if ((d->protocolCaps & Kopete::Protocol::BaseFgColor) || (d->protocolCaps & Kopete::Protocol::RichFgColor)) {
         richText |= KopeteRichTextWidget::SupportTextForegroundColor;
     }
     // Check for background color support
-    if ((d->protocolCaps & Kopete::Protocol::BaseBgColor) || (d->protocolCaps & Kopete::Protocol::RichBgColor))
-    {
+    if ((d->protocolCaps & Kopete::Protocol::BaseBgColor) || (d->protocolCaps & Kopete::Protocol::RichBgColor)) {
         richText |= KopeteRichTextWidget::SupportTextBackgroundColor;
     }
     // Check for alignment
-    if (d->protocolCaps & Kopete::Protocol::Alignment)
-    {
+    if (d->protocolCaps & Kopete::Protocol::Alignment) {
         richText |= KopeteRichTextWidget::SupportAlignment;
     }
 
     return richText;
 }
 
-void KopeteRichTextWidget::Private::mergeAll(const QTextCharFormat& format)
+void KopeteRichTextWidget::Private::mergeAll(const QTextCharFormat &format)
 {
     QTextCursor cursor = q->textCursor();
     cursor.beginEditBlock();
@@ -634,4 +599,3 @@ void KopeteRichTextWidget::Private::mergeAll(const QTextCharFormat& format)
 }
 
 // kate: space-indent on; indent-width 4; encoding utf-8; replace-tabs on;
-#include "kopeterichtextwidget.moc"
