@@ -18,11 +18,11 @@
 
 #include "history2dialog.h"
 
-#include <QtCore/QPointer>
-#include <QtCore/QDir>
-#include <QtCore/QTextStream>
-#include <QtGui/QClipboard>
-#include <QtGui/QTextDocument>
+#include <QPointer>
+#include <QDir>
+#include <QTextStream>
+#include <QClipboard>
+#include <QTextDocument>
 #include <QtAlgorithms>
 
 #include <kdebug.h>
@@ -167,7 +167,7 @@ History2Dialog::History2Dialog(Kopete::MetaContact *mc, QWidget *parent)
 
     connect(mHtmlPart->browserExtension(), SIGNAL(openUrlRequestDelayed(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
             this, SLOT(slotOpenURLRequest(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)));
-    connect(mMainWidget->dateTreeWidget, SIGNAL(itemClicked(QTreeWidgetItem *,int)), this, SLOT(dateSelected(QTreeWidgetItem *)));
+    connect(mMainWidget->dateTreeWidget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(dateSelected(QTreeWidgetItem*)));
     connect(mMainWidget->searchButton, SIGNAL(clicked()), this, SLOT(slotSearch()));
     connect(mMainWidget->searchLine, SIGNAL(returnPressed()), this, SLOT(slotSearch()));
     connect(mMainWidget->searchLine, SIGNAL(textChanged(QString)), this, SLOT(slotSearchTextChanged(QString)));
