@@ -6,10 +6,10 @@
     Copyright (c) 2002,2003,2004 by Will Stephenson <will@stevello.free-online.co.uk>
 
     Kopete    (c) 2002,2003,2004 by the Kopete developers  <kopete-devel@kde.org>
-	
-	Purpose: 
-	This class abstracts the interface to Kscd by
-	implementing NLMediaPlayer
+
+    Purpose:
+    This class abstracts the interface to Kscd by
+    implementing NLMediaPlayer
 
     *************************************************************************
     *                                                                       *
@@ -24,20 +24,19 @@
 #ifndef NLKSCD_H
 #define NLKSCD_H
 
-#include <QtDBus/QtDBus>
+#include <QtDBus>
 #include "nlmediaplayer.h"
 
 class QDBusInterface;
 
 class NLKscd : public NLMediaPlayer
 {
-	public:
-		NLKscd();
-		virtual ~NLKscd();
-		virtual void update();
-	private:
-		QDBusInterface *m_client;
-	
+public:
+    NLKscd();
+    virtual ~NLKscd();
+    virtual void update();
+private:
+    QDBusInterface *m_client;
 };
 
 #endif
