@@ -18,16 +18,14 @@
 
 #include <QDomDocument>
 
-QString KopeteXmlParserTests::test1 ( const QString & str ) {
-	
-	QDomDocument doc;
-	doc.setContent ( str );
-	
-	QDomElement body = doc.firstChildElement ( "message" ).firstChildElement ( "body" );
-	body.setAttribute ( "color", "red" );
-	body.firstChild().toText().setData ( "You are not a special or unique snowflake." );
-	
-	return doc.toString();
+QString KopeteXmlParserTests::test1(const QString &str)
+{
+    QDomDocument doc;
+    doc.setContent(str);
+
+    QDomElement body = doc.firstChildElement("message").firstChildElement("body");
+    body.setAttribute("color", "red");
+    body.firstChild().toText().setData("You are not a special or unique snowflake.");
+
+    return doc.toString();
 }
-
-
