@@ -1,10 +1,10 @@
 /*
     request.cpp - Kopete Groupwise Protocol
-  
-    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
+
+    Copyright (c) 2004      SUSE Linux AG	     http://www.suse.com
 
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
- 
+
     *************************************************************************
     *                                                                       *
     * This library is free software; you can redistribute it and/or         *
@@ -17,8 +17,9 @@
 
 #include "request.h"
 
-Request::Request( const int transactionId, const QString &command )
-: UserTransfer(transactionId), m_command( command )
+Request::Request(const int transactionId, const QString &command)
+    : UserTransfer(transactionId)
+    , m_command(command)
 {
 }
 
@@ -28,7 +29,5 @@ Request::~Request()
 
 QString Request::command()
 {
-	return m_command;
+    return m_command;
 }
-
-
