@@ -2,12 +2,12 @@
     Kopete Groupwise Protocol
     updateitemtask.cpp - ancestor for tasks that rename objects on the server
 
-    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
-    
+    Copyright (c) 2004      SUSE Linux AG	     http://www.suse.com
+
     Based on Iris, Copyright (C) 2003  Justin Karneges <justin@affinix.com>
 
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
- 
+
     *************************************************************************
     *                                                                       *
     * This library is free software; you can redistribute it and/or         *
@@ -20,20 +20,17 @@
 
 #include "updateitemtask.h"
 
-UpdateItemTask::UpdateItemTask( Task* parent) : RequestTask( parent )
+UpdateItemTask::UpdateItemTask(Task *parent) : RequestTask(parent)
 {
 }
 
-
 UpdateItemTask::~UpdateItemTask()
 {
 }
 
-void UpdateItemTask::item( Field::FieldList updateItemFields )
+void UpdateItemTask::item(Field::FieldList updateItemFields)
 {
-	Field::FieldList lst;
-	lst.append( new Field::MultiField( Field::NM_A_FA_CONTACT_LIST, NMFIELD_METHOD_VALID, 0, NMFIELD_TYPE_ARRAY, updateItemFields ) );
-	createTransfer( "updateitem", lst );
+    Field::FieldList lst;
+    lst.append(new Field::MultiField(Field::NM_A_FA_CONTACT_LIST, NMFIELD_METHOD_VALID, 0, NMFIELD_TYPE_ARRAY, updateItemFields));
+    createTransfer(QStringLiteral("updateitem"), lst);
 }
-
-#include "updateitemtask.moc"
