@@ -23,7 +23,7 @@
 
 #include <kconfig.h>
 #include <kglobal.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kopetecontact.h>
 #include <kopeteglobal.h>
 #include <kopetemetacontact.h>
@@ -54,8 +54,8 @@ ReceiveInvitationDialog::ReceiveInvitationDialog( GroupWiseAccount * account, co
 	else //something is very wrong
 		m_ui.contactName->setText( event.user );
 		
-	m_ui.dateTime->setText( KGlobal::locale()->formatDateTime( event.timeStamp ) );
-	m_ui.message->setText( QString("<b>%1</b>").arg( event.message ) );
+	m_ui.dateTime->setText( KLocale::global()->formatDateTime( event.timeStamp ) );
+	m_ui.message->setText( QStringLiteral("<b>%1</b>").arg( event.message ) );
 	
 	setMainWidget( wid );
 }
@@ -79,4 +79,3 @@ void ReceiveInvitationDialog::slotNoClicked()
 	deleteLater();
 }
 
-#include "gwreceiveinvitationdialog.moc"
