@@ -40,19 +40,17 @@
 #include <QAbstractSocket>
 #include <QPointer>
 
-#include <kcomponentdata.h>
 #include <kconfig.h>
-#include <kdebug.h>
+#include "jabber_protocol_debug.h"
 #include <kmessagebox.h>
 #include <knotification.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kaboutdata.h>
 #include <kpassworddialog.h>
-#include <kinputdialog.h>
-#include <kicon.h>
+#include <qinputdialog.h>
+#include <QIcon>
 #include <kactionmenu.h>
-#include <kglobal.h>
-#include <KComponentData>
+
 
 #include "kopetepassword.h"
 #include "kopetemetacontact.h"
@@ -79,6 +77,7 @@
 #include "jt_pubsub.h"
 
 #include <sys/utsname.h>
+#include <KSharedConfig>
 
 #ifdef LIBJINGLE_SUPPORT
 #include "libjingle.h"
@@ -90,22 +89,20 @@
 
 #define KOPETE_CAPS_NODE "http://kopete.kde.org/jabber/caps"
 
-
-
 JabberAccount::JabberAccount (JabberProtocol * parent, const QString & accountId)
 			  :Kopete::PasswordedAccount ( parent, accountId, false )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Instantiating new account " << accountId;
+    qCDebug(JABBER_PROTOCOL_LOG) << "Instantiating new account " << accountId;
 
 	m_protocol = parent;
 
 	m_jabberClient = new JabberClient;
 	
-	m_resourcePool = 0L;
-	m_contactPool = 0L;
+	m_resourcePool = nullptr;
+	m_contactPool = nullptr;
 
 #ifdef JINGLE_SUPPORT
-	m_jcm = 0L;
+	m_jcm = nullptr;
 #endif
 	m_bookmarks = new JabberBookmarks(this);
 	m_removing=false;
@@ -114,7 +111,7 @@ JabberAccount::JabberAccount (JabberProtocol * parent, const QString & accountId
 	JabberContact *myContact = contactPool()->addContact ( XMPP::RosterItem ( accountId ), Kopete::ContactList::self()->myself(), false );
 	setMyself( myContact );
 
-	m_initialPresence = XMPP::Status ( "", "", 5, true );
+	m_initialPresence = XMPP::Status ( QLatin1String(""), QLatin1String(""), 5, true );
 
 	// instantiate new client backend
 	QObject::connect ( m_jabberClient, SIGNAL (csDisconnected()), this, SLOT (slotCSDisconnected()) );
@@ -179,22 +176,22 @@ void JabberAccount::cleanup ()
 
 	delete m_jabberClient;
 	
-	m_jabberClient = 0L;
+	m_jabberClient = nullptr;
 
 	delete m_resourcePool;
-	m_resourcePool = 0L;
+	m_resourcePool = nullptr;
 
 	delete m_contactPool;
-	m_contactPool = 0L;
+	m_contactPool = nullptr;
 
 #ifdef LIBJINGLE_SUPPORT
 	delete m_libjingle;
-	m_libjingle = 0L;
+	m_libjingle = nullptr;
 #endif
 
 #ifdef JINGLE_SUPPORT
 	delete m_jcm;
-	m_jcm = 0L;
+	m_jcm = nullptr;
 #endif
 }
 
@@ -202,7 +199,7 @@ void JabberAccount::setS5BServerPort ( int port )
 {
 	if ( !m_jabberClient->setS5BServerPort ( port ) && !m_notifiedUserCannotBindTransferPort)
 	{
-		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (), KMessageBox::Sorry,
+		KMessageBox::sorry ( Kopete::UI::Global::mainWidget (),
 							 i18n ( "Could not bind the Jabber file transfer manager to a local port. Please check if the file transfer port is already in use, or choose another port in the account settings." ),
 							 i18n ( "Failed to start Jabber File Transfer Manager" ) );
 		m_notifiedUserCannotBindTransferPort = true;
@@ -212,16 +209,17 @@ void JabberAccount::setS5BServerPort ( int port )
 
 void JabberAccount::fillActionMenu( KActionMenu *actionMenu )
 {
+    qDebug() << " void JabberAccount::fillActionMenu( KActionMenu *actionMenu )";
 	Kopete::Account::fillActionMenu( actionMenu );
 
 	actionMenu->addSeparator();
 
-	KAction *action;
+	QAction *action;
 	
-	action = new KAction( this );
-	action->setIcon( KIcon("jabber_group") );
+	action = new QAction( this );
+	action->setIcon( QIcon::fromTheme(QStringLiteral("jabber_group")) );
 	action->setText( i18n("Join Groupchat...") );
-	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotJoinNewChat()) );
+    QObject::connect( action, &QAction::triggered, this, &JabberAccount::slotJoinNewChat );
 	actionMenu->addAction(action);
 	action->setEnabled( isConnected() );
 	
@@ -229,36 +227,35 @@ void JabberAccount::fillActionMenu( KActionMenu *actionMenu )
 	actionMenu->addAction(action);
 	action->setEnabled( isConnected() );
 
-
 	actionMenu->addSeparator();
 	
-	action = new KAction( this );
-	action->setIcon( KIcon("jabber_serv_on") );
+	action = new QAction( this );
+	action->setIcon( QIcon::fromTheme(QStringLiteral("jabber_serv_on")) );
 	action->setText( i18n ("Services...") );
-	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotGetServices()) );
+    QObject::connect( action, &QAction::triggered, this, &JabberAccount::slotGetServices );
 	action->setEnabled( isConnected() );
 	actionMenu->addAction( action );
 
-	action = new KAction( this );
-	action->setIcon( ( KIcon("mail-message-new") ) );
+	action = new QAction( this );
+	action->setIcon( ( QIcon::fromTheme(QStringLiteral("mail-message-new")) ) );
 	action->setText( i18n ("XML Console") );
-	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotXMPPConsole()) );
+    QObject::connect( action, &QAction::triggered, this, &JabberAccount::slotXMPPConsole );
 	actionMenu->addAction( action );
 
-	action = new KAction( this );
-	action->setIcon( ( KIcon("document-properties") ) );
+	action = new QAction( this );
+	action->setIcon( ( QIcon::fromTheme(QStringLiteral("document-properties")) ) );
 	action->setText( i18n ("Edit User Info...") );
-	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotEditVCard()) );
+    QObject::connect( action, &QAction::triggered, this, &JabberAccount::slotEditVCard );
 	action->setEnabled( isConnected() );
 	actionMenu->addAction( action );
 
 	KActionMenu *mMoodMenu = new KActionMenu(i18n("Set Mood"), actionMenu);
 	for(int i = 0; i <= Mood::Worried; i++)
 	{
-		action = new KAction(mMoodMenu);
+		action = new QAction(mMoodMenu);
 		action->setText(MoodManager::self()->getMoodName((Mood::Type)i));
 		action->setData(QVariant(i));
-		QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotSetMood()) );
+        QObject::connect( action, &QAction::triggered, this, &JabberAccount::slotSetMood );
 		mMoodMenu->addAction( action );
 	}
 	actionMenu->addAction( mMoodMenu );
@@ -317,8 +314,7 @@ bool JabberAccount::createContact (const QString & contactId,  Kopete::MetaConta
 void JabberAccount::errorConnectFirst ()
 {
 
-	KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
-									KMessageBox::Error,
+	KMessageBox::error ( Kopete::UI::Global::mainWidget (),
 									i18n ("Please connect first."), i18n ("Jabber Error") );
 
 }
@@ -334,13 +330,13 @@ bool JabberAccount::isConnecting ()
 	XMPP::Jid jid ( myself()->contactId () );
 
 	// see if we are currently trying to connect
-	return resourcePool()->bestResource ( jid ).status().show () == QString("connecting");
+	return resourcePool()->bestResource ( jid ).status().show () == QStringLiteral("connecting");
 
 }
 
 void JabberAccount::connectWithPassword ( const QString &password )
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "called";
+	qDebug (JABBER_PROTOCOL_LOG) << "called";
 
 	/* Cancel connection process if no password has been supplied. */
 	if ( password.isEmpty () )
@@ -380,7 +376,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 	m_jabberClient->setUseXOAuth2 ( configGroup()->readEntry ( "UseXOAuth2", false ) );
 
 	// enable file transfer (if empty, IP will be set after connection has been established)
-	KConfigGroup config = KGlobal::config()->group ( "Jabber" );
+	KConfigGroup config = KSharedConfig::openConfig()->group ( "Jabber" );
 	m_jabberClient->setFileTransfersEnabled ( true, config.readEntry ( "LocalIP" ) );
 	setS5BServerPort ( config.readEntry ( "LocalPort", 8010 ) );
 
@@ -393,20 +389,20 @@ void JabberAccount::connectWithPassword ( const QString &password )
 
 		uname (&utsBuf);
 
-		m_jabberClient->setClientName ("Kopete");
-		m_jabberClient->setClientVersion (KGlobal::mainComponent().aboutData()->version ());
-		m_jabberClient->setOSName (QString ("%1 %2").arg (utsBuf.sysname, 1).arg (utsBuf.release, 2));
+		m_jabberClient->setClientName (QStringLiteral("Kopete"));
+		m_jabberClient->setClientVersion (KAboutData::applicationData().version ());
+		m_jabberClient->setOSName (QStringLiteral ("%1 %2").arg (utsBuf.sysname, 1).arg (utsBuf.release, 2));
 	}
 
 	// Set caps node information
 	m_jabberClient->setCapsNode(KOPETE_CAPS_NODE);
-	m_jabberClient->setCapsVersion(KGlobal::mainComponent().aboutData()->version());
+	m_jabberClient->setCapsVersion(KAboutData::applicationData().version());
 	
 	// Set Disco Identity information
 	DiscoItem::Identity identity;
-	identity.category = "client";
-	identity.type = "pc";
-	identity.name = "Kopete";
+	identity.category = QStringLiteral("client");
+	identity.type = QStringLiteral("pc");
+	identity.name = QStringLiteral("Kopete");
 	m_jabberClient->setDiscoIdentity(identity);
 
 	//BEGIN TIMEZONE INFORMATION
@@ -440,19 +436,19 @@ void JabberAccount::connectWithPassword ( const QString &password )
 		timezoneString = str;
 	//END of timezone code
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Determined timezone " << timezoneString << " with UTC offset " << timezoneOffset << " hours.";
+	qDebug (JABBER_PROTOCOL_LOG) << "Determined timezone " << timezoneString << " with UTC offset " << timezoneOffset << " hours.";
 
 	m_jabberClient->setTimeZone ( timezoneString, timezoneOffset );
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Connecting to Jabber server " << server() << ":" << port();
+	qDebug (JABBER_PROTOCOL_LOG) << "Connecting to Jabber server " << server() << ":" << port();
 
-	setPresence( XMPP::Status ("connecting", "", 0, true) );
+	setPresence( XMPP::Status (QStringLiteral("connecting"), QLatin1String(""), 0, true) );
 
-	switch ( m_jabberClient->connect ( XMPP::Jid ( accountId () + QString("/") + resource () ), password ) )
+	switch ( m_jabberClient->connect ( XMPP::Jid ( accountId () + QStringLiteral("/") + resource () ), password ) )
 	{
 		case JabberClient::NoTLS:
 			// no SSL support, at the connecting stage this means the problem is client-side
-			KMessageBox::queuedMessageBox(Kopete::UI::Global::mainWidget (), KMessageBox::Error,
+			KMessageBox::error(Kopete::UI::Global::mainWidget (),
 								i18n ("SSL support could not be initialized for account %1. This is most likely because TLS support for QCA is not available.",
 								myself()->contactId()),
 								i18n ("Jabber SSL Error"));
@@ -474,7 +470,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 void JabberAccount::slotClientDebugMessage ( const QString &msg )
 {
 
-	kDebug (JABBER_DEBUG_PROTOCOL) << msg;
+    qCDebug(JABBER_PROTOCOL_LOG) << msg;
 
 }
 
@@ -494,15 +490,15 @@ bool JabberAccount::handleTLSWarning (
 			break;
 		case QCA::TLS::HostMismatch:
 			idString = i18n("The host name does not match the one in the certificate.");
-			idCode   = "HostMismatch";
+			idCode   = QStringLiteral("HostMismatch");
 			break;
 		case QCA::TLS::InvalidCertificate:
 			idString = i18n("The certificate is invalid.");
-			idCode   = "InvalidCert";
+			idCode   = QStringLiteral("InvalidCert");
 			break;
 		case QCA::TLS::NoCertificate:
 			idString = i18n("No certificate was presented.");
-			idCode   = "NoCert";
+			idCode   = QStringLiteral("NoCert");
 			break;
 	}
 
@@ -512,47 +508,47 @@ bool JabberAccount::handleTLSWarning (
 			break;
 		case QCA::ErrorRejected:
 			validityString = i18n("The Certificate Authority rejected the certificate.");
-			code = "Rejected";
+			code = QStringLiteral("Rejected");
 			break;
 		case QCA::ErrorUntrusted:
 			validityString = i18n("The certificate is not trusted.");
-			code = "Untrusted";
+			code = QStringLiteral("Untrusted");
 			break;
 		case QCA::ErrorSignatureFailed:
 			validityString = i18n("The signature is invalid.");
-			code = "SignatureFailed";
+			code = QStringLiteral("SignatureFailed");
 			break;
 		case QCA::ErrorInvalidCA:
 			validityString = i18n("The Certificate Authority is invalid.");
-			code = "InvalidCA";
+			code = QStringLiteral("InvalidCA");
 			break;
 		case QCA::ErrorInvalidPurpose:
 			validityString = i18n("Invalid certificate purpose.");
-			code = "InvalidPurpose";
+			code = QStringLiteral("InvalidPurpose");
 			break;
 		case QCA::ErrorSelfSigned:
 			validityString = i18n("The certificate is self-signed.");
-			code = "SelfSigned";
+			code = QStringLiteral("SelfSigned");
 			break;
 		case QCA::ErrorRevoked:
 			validityString = i18n("The certificate has been revoked.");
-			code = "Revoked";
+			code = QStringLiteral("Revoked");
 			break;
 		case QCA::ErrorPathLengthExceeded:
 			validityString = i18n("Maximum certificate chain length was exceeded.");
-			code = "PathLengthExceeded";
+			code = QStringLiteral("PathLengthExceeded");
 			break;
 		case QCA::ErrorExpired:
 			validityString = i18n("The certificate has expired.");
-			code = "Expired";
+			code = QStringLiteral("Expired");
 			break;
 		case QCA::ErrorExpiredCA:
 			validityString = i18n("The Certificate Authority has expired.");
-			code = "ExpiredCA";
+			code = QStringLiteral("ExpiredCA");
 			break;
 		case QCA::ErrorValidityUnknown:
 			validityString = i18n("Validity is unknown.");
-			code = "ValidityUnknown";
+			code = QStringLiteral("ValidityUnknown");
 			break;
 	}
 
@@ -582,7 +578,7 @@ bool JabberAccount::handleTLSWarning (
 					  message,
 					  i18n("Jabber Connection Certificate Problem"),
 					  KStandardGuiItem::cont(),KStandardGuiItem::cancel(),
-					  QString("KopeteTLSWarning") + server + idCode + code) == KMessageBox::Continue );
+					  QStringLiteral("KopeteTLSWarning") + server + idCode + code) == KMessageBox::Continue );
 
 }
 
@@ -590,7 +586,7 @@ void JabberAccount::slotHandleTLSWarning (
 		QCA::TLS::IdentityResult identityResult,
 		QCA::Validity validityResult )
 {
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Handling TLS warning...";
+    qCDebug(JABBER_PROTOCOL_LOG) << "Handling TLS warning...";
 
 	if ( handleTLSWarning ( m_jabberClient, identityResult, validityResult ) )
 	{
@@ -607,13 +603,13 @@ void JabberAccount::slotHandleTLSWarning (
 
 void JabberAccount::slotClientError ( JabberClient::ErrorCode errorCode )
 {
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Handling client error...";
+    qCDebug(JABBER_PROTOCOL_LOG) << "Handling client error...";
 
 	switch ( errorCode )
 	{
 		case JabberClient::NoTLS:
 		default:
-			KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (), KMessageBox::Error,
+			KMessageBox::error ( Kopete::UI::Global::mainWidget (),
 					     i18n ("An encrypted connection with the Jabber server could not be established."),
 					     i18n ("Jabber Connection Error"));
 			disconnect ( Kopete::Account::Manual );
@@ -624,18 +620,18 @@ void JabberAccount::slotClientError ( JabberClient::ErrorCode errorCode )
 
 void JabberAccount::slotConnected ()
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Connected to Jabber server.";
+	qDebug (JABBER_PROTOCOL_LOG) << "Connected to Jabber server.";
 
 #ifdef LIBJINGLE_SUPPORT
 	loginLibjingle();
 #endif
 
 #ifdef JINGLE_SUPPORT
-	qDebug() << "Create JingleCallsManager";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Create JingleCallsManager";
 	m_jcm = new JingleCallsManager(this);
 #endif
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Requesting roster...";
+	qDebug (JABBER_PROTOCOL_LOG) << "Requesting roster...";
 	m_jabberClient->requestRoster ();
 }
 
@@ -654,7 +650,7 @@ void JabberAccount::slotRosterRequestFinished ( bool success )
 	* information before we have updated our roster with actual
 	* contacts from the server! (Iris won't forward presence
 	* information in that case either). */
-	kDebug (JABBER_DEBUG_GLOBAL) << "Setting initial presence...";
+	qDebug (JABBER_PROTOCOL_LOG) << "Setting initial presence...";
 	setPresence ( m_initialPresence );
 
 }
@@ -678,7 +674,7 @@ void JabberAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const K
 			m_libjingle->logout();
 		#endif
 			xmppStatus.setIsAvailable( false );
-			kDebug (JABBER_DEBUG_GLOBAL) << "CROSS YOUR FINGERS! THIS IS GONNA BE WILD";
+			qDebug (JABBER_PROTOCOL_LOG) << "CROSS YOUR FINGERS! THIS IS GONNA BE WILD";
 			disconnect (Manual, xmppStatus);	
 			return;
     	}
@@ -687,7 +683,6 @@ void JabberAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const K
 	{
 		return;
 	}
-	
 
 	if ( !isConnected () )
 	{
@@ -711,19 +706,19 @@ void JabberAccount::setStatusMessage( const Kopete::StatusMessage &statusMessage
 
 void JabberAccount::disconnect ( Kopete::Account::DisconnectReason reason )
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "disconnect() called";
+	qDebug (JABBER_PROTOCOL_LOG) << "disconnect() called";
 
 	if (isConnected ())
 	{
-		kDebug (JABBER_DEBUG_GLOBAL) << "Still connected, closing connection...";
+		qDebug (JABBER_PROTOCOL_LOG) << "Still connected, closing connection...";
 		/* Tell backend class to disconnect. */
 		m_jabberClient->disconnect ();
 	}
 
 	// make sure that the connection animation gets stopped if we're still
 	// in the process of connecting
-	setPresence ( XMPP::Status ("", "", 0, false) );
-	m_initialPresence = XMPP::Status ("", "", 5, true);
+	setPresence ( XMPP::Status (QLatin1String(""), QLatin1String(""), 0, false) );
+	m_initialPresence = XMPP::Status (QLatin1String(""), QLatin1String(""), 5, true);
 
 	/* FIXME:
 	 * We should delete the JabberClient instance here,
@@ -733,18 +728,18 @@ void JabberAccount::disconnect ( Kopete::Account::DisconnectReason reason )
 	 * Instead, the instance will lurk until the next
 	 * connection attempt.
 	 */
-	kDebug (JABBER_DEBUG_GLOBAL) << "Disconnected.";
+	qDebug (JABBER_PROTOCOL_LOG) << "Disconnected.";
 
 	disconnected ( reason );
 }
 
 void JabberAccount::disconnect( Kopete::Account::DisconnectReason reason, XMPP::Status &status )
 {
-    kDebug (JABBER_DEBUG_GLOBAL) << "disconnect( reason, status ) called";
+    qDebug (JABBER_PROTOCOL_LOG) << "disconnect( reason, status ) called";
     
 	if (isConnected ())
 	{
-		kDebug (JABBER_DEBUG_GLOBAL) << "Still connected, closing connection...";
+		qDebug (JABBER_PROTOCOL_LOG) << "Still connected, closing connection...";
 		/* Tell backend class to disconnect. */
 		m_jabberClient->disconnect (status);
 	}
@@ -761,7 +756,7 @@ void JabberAccount::disconnect( Kopete::Account::DisconnectReason reason, XMPP::
 	 * Instead, the instance will lurk until the next
 	 * connection attempt.
 	 */
-	kDebug (JABBER_DEBUG_GLOBAL) << "Disconnected.";
+	qDebug (JABBER_PROTOCOL_LOG) << "Disconnected.";
 
 	Kopete::Account::disconnected ( reason );
 }
@@ -783,7 +778,7 @@ void JabberAccount::slotDisconnect ()
 
 void JabberAccount::slotCSDisconnected ()
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Disconnected from Jabber server.";
+	qDebug (JABBER_PROTOCOL_LOG) << "Disconnected from Jabber server.";
 
 	/*
 	 * We should delete the JabberClient instance here,
@@ -799,7 +794,7 @@ void JabberAccount::slotCSDisconnected ()
 
 #ifdef JINGLE_SUPPORT
 	delete m_jcm;
-	m_jcm = 0L;
+	m_jcm = nullptr;
 #endif
 
 }
@@ -1036,28 +1031,28 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 			errorText += "\n" + additionalErrMsg;
 		}
 
-		KNotification::event( QLatin1String("connection_error"), i18n("Kopete: Connection problem with Jabber server %1", server),
+		KNotification::event( QStringLiteral("connection_error"), i18n("Kopete: Connection problem with Jabber server %1", server),
 		                      errorText,
-		                      KIconLoader::global()->iconPath( "jabber_protocol", KIconLoader::Dialog ),
+		                      KIconLoader::global()->iconPath( QStringLiteral("jabber_protocol"), KIconLoader::Dialog ),
 		                      Kopete::UI::Global::mainWidget() );
 	}
 }
 
 void JabberAccount::slotCSError ( int error )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Error in stream signalled.";
+    qCDebug(JABBER_PROTOCOL_LOG) << "Error in stream signalled.";
 
 	if ( ( error == XMPP::ClientStream::ErrAuth )
 		&& ( client()->clientStream()->errorCondition () == XMPP::ClientStream::NotAuthorized ) )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Incorrect password, retrying.";
+        qCDebug(JABBER_PROTOCOL_LOG) << "Incorrect password, retrying.";
 		disconnect(Kopete::Account::BadPassword);
 	}
 	else
 	{
 		Kopete::Account::DisconnectReason errorClass =  Kopete::Account::Unknown;
 
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Disconnecting.";
+        qCDebug(JABBER_PROTOCOL_LOG) << "Disconnecting.";
 
 		// display message to user
 		// when removing or disconnecting, connection errors are normal
@@ -1076,7 +1071,7 @@ void JabberAccount::slotCSError ( int error )
 /* Set presence (usually called by dialog widget). */
 void JabberAccount::setPresence ( const XMPP::Status &status )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Status: " << status.show () << ", Reason: " << status.status ();
+    qCDebug(JABBER_PROTOCOL_LOG) << "Status: " << status.show () << ", Reason: " << status.status ();
 
 	// fetch input status
 	XMPP::Status newStatus = status;
@@ -1095,7 +1090,7 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 		newPriority = configGroup()->readEntry( "AwayPriority", 0 );
 	}
 	newStatus.setPriority ( newPriority );
-	kDebug(JABBER_DEBUG_GLOBAL) << "New priority: " << newPriority;
+    qCDebug(JABBER_PROTOCOL_LOG) << "New priority: " << newPriority;
 
 	XMPP::Jid jid;
 
@@ -1110,7 +1105,7 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 
 	XMPP::Resource oldResource ( m_lastResource );
 
-	kDebug(JABBER_DEBUG_GLOBAL) << "Old resource:" << m_lastResource;
+    qCDebug(JABBER_PROTOCOL_LOG) << "Old resource:" << m_lastResource;
 
 	// update resource from jabber client
 	m_lastResource = jid.resource();
@@ -1134,19 +1129,19 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 			resourcePool()->removeResource ( jid, oldResource );
 	}
 
-	kDebug(JABBER_DEBUG_GLOBAL) << "New resource:" << m_lastResource;
+    qCDebug(JABBER_PROTOCOL_LOG) << "New resource:" << m_lastResource;
 
 	/*
 	 * Unless we are in the connecting status, send a presence packet to the server
 	 */
-	if(status.show () != QString("connecting") )
+	if(status.show () != QStringLiteral("connecting") )
 	{
 		/*
 		 * Make sure we are actually connected before sending out a packet.
 		 */
 		if (isConnected())
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "Sending new presence to the server.";
+            qCDebug(JABBER_PROTOCOL_LOG) << "Sending new presence to the server.";
 
 			XMPP::JT_Presence * task = new XMPP::JT_Presence ( client()->rootTask ());
 
@@ -1164,7 +1159,7 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 		}
 		else
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "We were not connected, presence update aborted.";
+            qCDebug(JABBER_PROTOCOL_LOG) << "We were not connected, presence update aborted.";
 		}
 	}
 
@@ -1194,25 +1189,25 @@ void JabberAccount::slotXMPPConsole ()
 
 void JabberAccount::slotSetMood()
 {
-	KAction *action = (KAction *)sender();
+	QAction *action = (QAction *)sender();
 	Mood::Type type = (Mood::Type)action->data().toInt();
 
-    PubSubItem psi("current", Mood(type).toXml(*client()->client()->rootTask()->doc()));
-    JT_PubSubPublish *task = new JT_PubSubPublish(client()->client()->rootTask(), QString("http://jabber.org/protocol/mood"), psi);
+    PubSubItem psi(QStringLiteral("current"), Mood(type).toXml(*client()->client()->rootTask()->doc()));
+    JT_PubSubPublish *task = new JT_PubSubPublish(client()->client()->rootTask(), QStringLiteral("http://jabber.org/protocol/mood"), psi);
     task->go(true);
 
 }
 
 void JabberAccount::slotSubscription (const XMPP::Jid & jid, const QString & type)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << jid.full () << ", " << type;
+	qDebug (JABBER_PROTOCOL_LOG) << jid.full () << ", " << type;
 
-	if (type == "subscribe")
+	if (type == QLatin1String("subscribe"))
 	{
 		/*
 		 * A user wants to subscribe to our presence.
 		 */
-		kDebug (JABBER_DEBUG_GLOBAL) << jid.full () << " is asking for authorization to subscribe.";
+		qDebug (JABBER_PROTOCOL_LOG) << jid.full () << " is asking for authorization to subscribe.";
 
 		// Is the user already in our contact list?
 		JabberBaseContact *contact = contactPool()->findExactMatch( jid );
@@ -1233,12 +1228,12 @@ void JabberAccount::slotSubscription (const XMPP::Jid & jid, const QString & typ
 		event->showActions( actions );
 		event->sendEvent();
 	}
-	else if (type == "unsubscribed")
+	else if (type == QLatin1String("unsubscribed"))
 	{
 		/*
 		 * Someone else removed our authorization to see them.
 		 */
-		kDebug (JABBER_DEBUG_GLOBAL) << jid.full() << " revoked our presence authorization";
+		qDebug (JABBER_PROTOCOL_LOG) << jid.full() << " revoked our presence authorization";
 
 		XMPP::JT_Roster *task;
 
@@ -1290,7 +1285,7 @@ void JabberAccount::slotAddedInfoEventActionActivated ( uint actionId )
 		* Authorize user.
 		*/
 		XMPP::JT_Presence *task = new XMPP::JT_Presence ( client()->rootTask () );
-		task->sub ( jid, "subscribed" );
+		task->sub ( jid, QStringLiteral("subscribed") );
 		task->go ( true );
 	}
 	else if ( actionId == Kopete::AddedInfoEvent::BlockAction )
@@ -1299,7 +1294,7 @@ void JabberAccount::slotAddedInfoEventActionActivated ( uint actionId )
 		* Reject subscription.
 		*/
 		XMPP::JT_Presence *task = new XMPP::JT_Presence ( client()->rootTask () );
-		task->sub ( jid, "unsubscribed" );
+		task->sub ( jid, QStringLiteral("unsubscribed") );
 		task->go ( true );
 	}
 	else if( actionId == Kopete::AddedInfoEvent::AddContactAction )
@@ -1335,14 +1330,12 @@ void JabberAccount::slotAddedInfoEventActionActivated ( uint actionId )
 			// send a subscription request.
 			XMPP::JT_Presence *presenceTask = new XMPP::JT_Presence ( client()->rootTask () );
 	
-			presenceTask->sub ( jid, "subscribe" );
+			presenceTask->sub ( jid, QStringLiteral("subscribe") );
 			presenceTask->go ( true );
 		}
 	}
 }
 
-
-
 void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 {
 
@@ -1361,7 +1354,7 @@ void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 	 * a roster item here.
 	 */
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "New roster item " << item.jid().full () << " (Subscription: " << item.subscription().toString () << ")";
+	qDebug (JABBER_PROTOCOL_LOG) << "New roster item " << item.jid().full () << " (Subscription: " << item.subscription().toString () << ")";
 
 	/*
 	 * See if the contact need to be added, according to the criterias of 
@@ -1445,7 +1438,7 @@ void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 		Kopete::MetaContact *metaContact=c->metaContact();
 		if(metaContact->isTemporary())
 			return;
-		kDebug (JABBER_DEBUG_GLOBAL) << c->contactId() << 
+		qDebug (JABBER_PROTOCOL_LOG) << c->contactId() << 
 				" is on the contact list while it should not.  we are removing it.  - " << c << endl;
 		delete c;
 		if(metaContact->contacts().isEmpty())
@@ -1456,7 +1449,7 @@ void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 
 void JabberAccount::slotContactDeleted (const XMPP::RosterItem & item)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Deleting contact " << item.jid().full ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Deleting contact " << item.jid().full ();
 
 	// since the contact instance will get deleted here, the GUI should be updated
 	contactPool()->removeContact ( item.jid () );
@@ -1465,11 +1458,11 @@ void JabberAccount::slotContactDeleted (const XMPP::RosterItem & item)
 
 void JabberAccount::slotReceivedMessage (const XMPP::Message & message)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "New message from " << message.from().full ();
+	qDebug (JABBER_PROTOCOL_LOG) << "New message from " << message.from().full ();
 
 	JabberBaseContact *contactFrom;
 
-	if ( message.type() == "groupchat" )
+	if ( message.type() == QLatin1String("groupchat") )
 	{
 		// this is a groupchat message, forward it to the group contact
 		// (the one without resource name)
@@ -1486,7 +1479,7 @@ void JabberAccount::slotReceivedMessage (const XMPP::Message & message)
 		 */
 		if ( !contactFrom )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "WARNING: Received a groupchat message but could not find room contact. Ignoring message.";
+            qCDebug(JABBER_PROTOCOL_LOG) << "WARNING: Received a groupchat message but could not find room contact. Ignoring message.";
 			return;
 		}
 	}
@@ -1513,7 +1506,7 @@ void JabberAccount::slotReceivedMessage (const XMPP::Message & message)
 			XMPP::Jid jid ( message.from().bare() );
 
 			// the contact is not in our pool, add it as a temporary contact
-			kDebug (JABBER_DEBUG_GLOBAL) << jid.full () << " is unknown to us, creating temporary contact.";
+			qDebug (JABBER_PROTOCOL_LOG) << jid.full () << " is unknown to us, creating temporary contact.";
 
 			Kopete::MetaContact *metaContact = new Kopete::MetaContact ();
 
@@ -1550,7 +1543,7 @@ void JabberAccount::slotJoinNewChat ()
 
 void JabberAccount::slotGroupChatJoined (const XMPP::Jid & jid)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Joined groupchat " << jid.full ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Joined groupchat " << jid.full ();
 
 	// Create new meta contact that holds the groupchat contact.
 	Kopete::MetaContact *metaContact = new Kopete::MetaContact ();
@@ -1587,7 +1580,7 @@ void JabberAccount::slotGroupChatJoined (const XMPP::Jid & jid)
 
 void JabberAccount::slotGroupChatLeft (const XMPP::Jid & jid)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Left groupchat " << jid.full ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Left groupchat " << jid.full ();
 	
 	// remove group contact from list
 	Kopete::Contact *contact = 
@@ -1609,20 +1602,20 @@ void JabberAccount::slotGroupChatLeft (const XMPP::Jid & jid)
 
 void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::Status & status)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Received groupchat presence for room " << jid.full ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Received groupchat presence for room " << jid.full ();
 
 	// fetch room contact (the one without resource)
 	JabberGroupContact *groupContact = dynamic_cast<JabberGroupContact *>( contactPool()->findExactMatch ( XMPP::Jid ( jid.bare() ) ) );
 
 	if ( !groupContact )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "WARNING: Groupchat presence signalled, but we do not have a room contact?";
+        qCDebug(JABBER_PROTOCOL_LOG) << "WARNING: Groupchat presence signalled, but we do not have a room contact?";
 		return;
 	}
 
 	if ( !status.isAvailable () )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << jid.full () << " has become unavailable, removing from room";
+        qCDebug(JABBER_PROTOCOL_LOG) << jid.full () << " has become unavailable, removing from room";
 
 		// remove the resource from the pool
 		resourcePool()->removeResource ( jid, XMPP::Resource ( jid.resource (), status ) );
@@ -1643,7 +1636,7 @@ void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::St
 
 void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const QString &reason)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Group chat error - room " << jid.full () << " had error " << error << " (" << reason << ")";
+	qDebug (JABBER_PROTOCOL_LOG) << "Group chat error - room " << jid.full () << " had error " << error << " (" << reason << ")";
 
 	switch (error)
 	{
@@ -1660,8 +1653,8 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const Q
 	case JabberClient::NicknameConflict:
 		{
 			bool ok;
-			QString nickname = KInputDialog::getText(i18n("Error trying to join %1 : nickname %2 is already in use", jid.node(), jid.resource()),
-									i18n("Provide your nickname"),
+            QString nickname = QInputDialog::getText(nullptr, i18n("Error trying to join %1 : nickname %2 is already in use", jid.node(), jid.resource()),
+                                    i18n("Provide your nickname"), QLineEdit::Normal,
 									QString(),
 									&ok);
 			if (ok)
@@ -1672,15 +1665,13 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const Q
 		break;
 
 	case JabberClient::BannedFromThisMUC:
-		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
-									KMessageBox::Error,
+		KMessageBox::error ( Kopete::UI::Global::mainWidget (),
 									i18n ("You cannot join the room %1 because you have been banned", jid.node()),
 									i18n ("Jabber Group Chat") );
 		break;
 
 	case JabberClient::MaxUsersReachedForThisMuc:
-		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
-									KMessageBox::Error,
+		KMessageBox::error ( Kopete::UI::Global::mainWidget (),
 									i18n ("You cannot join the room %1 because the maximum number of users has been reached", jid.node()),
 									i18n ("Jabber Group Chat") );
 		break;
@@ -1689,8 +1680,7 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const Q
 		{
 		QString detailedReason = reason.isEmpty () ? i18n ( "No reason given by the server" ) : reason;
 
-		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
-									KMessageBox::Error,
+		KMessageBox::error ( Kopete::UI::Global::mainWidget (),
 									i18n ("There was an error processing your request for groupchat %1. (Reason: %2, Code %3)", jid.full (), detailedReason, error ),
 									i18n ("Jabber Group Chat") );
 		}
@@ -1700,7 +1690,7 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const Q
 void JabberAccount::slotResourceAvailable (const XMPP::Jid & jid, const XMPP::Resource & resource)
 {
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "New resource available for " << jid.full();
+	qDebug (JABBER_PROTOCOL_LOG) << "New resource available for " << jid.full();
 
 	resourcePool()->addResource ( jid, resource );
 
@@ -1709,7 +1699,7 @@ void JabberAccount::slotResourceAvailable (const XMPP::Jid & jid, const XMPP::Re
 void JabberAccount::slotResourceUnavailable (const XMPP::Jid & jid, const XMPP::Resource & resource)
 {
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Resource now unavailable for " << jid.full ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Resource now unavailable for " << jid.full ();
 
 	resourcePool()->removeResource ( jid, resource );
 
@@ -1768,8 +1758,8 @@ bool JabberAccount::removeAccount( )
 				   			    "If you unregister, your whole contact list may be removed from the server,"
 							    " and you will never be able to connect to this account with any client", accountLabel() ),
 					i18n("Unregister"),
-					KGuiItem(i18n( "Remove and Unregister" ), "edit-delete"),
-					KGuiItem(i18n( "Remove only from Kopete"), "user-trash"),KStandardGuiItem::cancel(),
+					KGuiItem(i18n( "Remove and Unregister" ), QStringLiteral("edit-delete")),
+					KGuiItem(i18n( "Remove only from Kopete"), QStringLiteral("user-trash")),KStandardGuiItem::cancel(),
 					QString(), KMessageBox::Notify | KMessageBox::Dangerous );
 		if(result == KMessageBox::Cancel)
 		{
@@ -1812,7 +1802,7 @@ void JabberAccount::slotUnregisterFinished( )
 
 	if ( task && ! task->success ())
 	{
-		KMessageBox::queuedMessageBox ( 0L, KMessageBox::Error,
+		KMessageBox::error ( 0L,
 			i18n ("An error occurred while trying to remove the account:\n%1", task->statusString()),
 			i18n ("Jabber Account Unregistration"));
 		m_removing=false;
@@ -1860,7 +1850,7 @@ void JabberAccount::loginLibjingleResolver(const QHostAddress &address, quint16
 		resolver->deleteLater();
 	}
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "address:" << address.toString() << "port:" << port;
+	qDebug (JABBER_PROTOCOL_LOG) << "address:" << address.toString() << "port:" << port;
 
 	m_libjingle->setServer(address.toString(), port);
 	m_libjingle->login();
@@ -1915,11 +1905,11 @@ bool JabberAccount::oldEncrypted()
 
 /*
 JabberMoodAction::JabberMoodAction(const Mood::Type type, QObject *parent):
-KAction(parent)
+QAction(parent)
 {
 	mType = type;
 	setText(MoodManager::self()->getMoodName(mType));
-	//setIcon( KIcon( QString( "icq_xstatus%1" ).arg( mStatus.status() ) ) );
+	//setIcon( QIcon::fromTheme( QString( "icq_xstatus%1" ).arg( mStatus.status() ) ) );
 	//setToolTip();
 	QObject::connect(this, SIGNAL(triggered(bool)), this, SLOT(triggered()));
 }
@@ -1929,6 +1919,3 @@ void JabberMoodAction::triggered()
 	emit triggered(mType);
 }*/
 
-#include "jabberaccount.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
