@@ -32,17 +32,18 @@
 #include <QList>
 
 #include <KActionCollection>
-#include <kdebug.h>
-#include <klocale.h>
+#include "jabber_protocol_debug.h"
+#include <KLocalizedString>
 #include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kaction.h>
+#include <QAction>
 #include <kactionmenu.h>
 #include <kicon.h>
-#include <kstandarddirs.h>
+
 #include <kio/netaccess.h>
-#include <kinputdialog.h>
+#include <qinputdialog.h>
 #include <kopeteview.h>
+#include <QStandardPaths>
+#include <QFileDialog>
 
 #include "kopetecontactlist.h"
 #include "kopetegroup.h"
@@ -69,13 +70,14 @@
  * JabberContact constructor
  */
 JabberContact::JabberContact (const XMPP::RosterItem &rosterItem, Kopete::Account *_account, Kopete::MetaContact * mc, const QString &legacyId)
-	: JabberBaseContact ( rosterItem, _account, mc, legacyId)  , mDiscoDone(false), m_syncTimer(0L)
+	: JabberBaseContact ( rosterItem, _account, mc, legacyId)  , mDiscoDone(false), m_syncTimer(nullptr)
 {
 	///*account()->client()->clientStream()->*/XMPP::setDebug((Debug*) new TD());
-	kDebug(JABBER_DEBUG_GLOBAL) << contactId() << "  is created  - " << this;
+	qCDebug(JABBER_PROTOCOL_LOG) << contactId() << "  is created  - " << this;
 	// this contact is able to transfer files
 	setFileCapable ( true );
-	
+    const QString jabberPhotoPath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "jabberphotos/";
+    QDir().mkpath(jabberPhotoPath);
 
 	/*
 	 * Catch when we're going online for the first time to
@@ -131,34 +133,34 @@ JabberContact::JabberContact (const XMPP::RosterItem &rosterItem, Kopete::Accoun
 
 JabberContact::~JabberContact()
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << contactId() << "  is destroyed  - " << this;
+	qCDebug(JABBER_PROTOCOL_LOG) << contactId() << "  is destroyed  - " << this;
 }
 
-QList<KAction*> *JabberContact::customContextMenuActions ()
+QList<QAction *> *JabberContact::customContextMenuActions ()
 {
 
-	QList<KAction*> *actions = new QList<KAction*>();
+	QList<QAction *> *actions = new QList<QAction*>();
 
-	KActionMenu *actionAuthorization = new KActionMenu ( KIcon("network-connect"), i18n ("Authorization"), this);
+    KActionMenu *actionAuthorization = new KActionMenu ( QIcon::fromTheme(QStringLiteral("network-connect")), i18n ("Authorization"), this);
 
-	KAction *resendAuthAction, *requestAuthAction, *removeAuthAction;
+	QAction *resendAuthAction, *requestAuthAction, *removeAuthAction;
 	
-	resendAuthAction = new KAction( this );
-	resendAuthAction->setIcon( (KIcon("mail-forward") ) );
+	resendAuthAction = new QAction( this );
+    resendAuthAction->setIcon( QIcon::fromTheme(QStringLiteral("mail-forward")) );
 	resendAuthAction->setText( i18n ("(Re)send Authorization To") );
 	resendAuthAction->setEnabled( mRosterItem.subscription().type() == XMPP::Subscription::To || mRosterItem.subscription().type() == XMPP::Subscription::None );
 	connect(resendAuthAction, SIGNAL(triggered(bool)), SLOT(slotSendAuth()));
 	actionAuthorization->addAction(resendAuthAction);
 
-	requestAuthAction = new KAction( this );
-	requestAuthAction->setIcon( (KIcon("mail-reply-sender") ) );
+	requestAuthAction = new QAction( this );
+    requestAuthAction->setIcon( QIcon::fromTheme(QStringLiteral("mail-reply-sender")) );
 	requestAuthAction->setText( i18n ("(Re)request Authorization From") );
 	requestAuthAction->setEnabled( mRosterItem.subscription().type() == XMPP::Subscription::From || mRosterItem.subscription().type() == XMPP::Subscription::None );
 	connect(requestAuthAction, SIGNAL(triggered(bool)), SLOT(slotRequestAuth()));
 	actionAuthorization->addAction(requestAuthAction);
 	
-	removeAuthAction = new KAction( this );
-	removeAuthAction->setIcon( (KIcon("edit-delete") ) );
+	removeAuthAction = new QAction( this );
+    removeAuthAction->setIcon( QIcon::fromTheme(QStringLiteral("edit-delete")) );
 	removeAuthAction->setText( i18n ("Remove Authorization From") );
 	removeAuthAction->setEnabled( mRosterItem.subscription().type() == XMPP::Subscription::Both || mRosterItem.subscription().type() == XMPP::Subscription::From );
 	connect(removeAuthAction, SIGNAL(triggered(bool)), SLOT(slotRemoveAuth()));
@@ -168,9 +170,9 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 
 	if ( account()->enabledLibjingle() ) {
 
-		KAction *libjingleCallAction;
-		libjingleCallAction = new KAction( this );
-		libjingleCallAction->setIcon( (KIcon("voicecall") ) );
+		QAction *libjingleCallAction;
+		libjingleCallAction = new QAction( this );
+        libjingleCallAction->setIcon( (QIcon::fromTheme("voicecall") ) );
 		libjingleCallAction->setText( i18n ("Call contact") );
 		libjingleCallAction->setEnabled( account()->supportLibjingle(contactId()) );
 		connect(libjingleCallAction, SIGNAL(triggered(bool)), SLOT(makeLibjingleCallAction()));
@@ -180,23 +182,23 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 
 #endif
 
-	KActionMenu *actionSetAvailability = new KActionMenu ( KIcon("user-identity", 0, QStringList() << QString() << "user-online"), i18n ("Set Availability"), this );
+    KActionMenu *actionSetAvailability = new KActionMenu ( KIcon(QStringLiteral("user-identity"), 0, QStringList() << QString() << QStringLiteral("user-online")), i18n ("Set Availability"), this );
 
-#define KACTION(status, text, name, slot) \
-	{ KAction *tmp = new KAction(this); \
-	tmp->setIcon( KIcon(QIcon((status).iconFor(this)))); \
+#define QAction(status, text, name, slot) \
+	{ QAction *tmp = new QAction(this); \
+    tmp->setIcon( QIcon((status).iconFor(this))); \
 	tmp->setText( text ); \
 	connect(tmp, SIGNAL(triggered(bool)), (slot));\
 	actionSetAvailability->addAction(tmp); }
 
-	KACTION( protocol()->JabberKOSOnline, i18n ("Online"),         "actionOnline", SLOT(slotStatusOnline()) );
-	KACTION( protocol()->JabberKOSChatty, i18n ("Free to Chat"),   "actionChatty", SLOT(slotStatusChatty()) );
-	KACTION( protocol()->JabberKOSAway,   i18n ("Away"),           "actionAway",   SLOT(slotStatusAway()) );
-	KACTION( protocol()->JabberKOSXA,     i18n ("Extended Away"),  "actionXA",     SLOT(slotStatusXA()) );
-	KACTION( protocol()->JabberKOSDND,    i18n ("Do Not Disturb"), "actionDND",    SLOT(slotStatusDND()) );
-	KACTION( protocol()->JabberKOSInvisible, i18n ("Invisible"),   "actionInvisible", SLOT(slotStatusInvisible()) );
+    QAction( protocol()->JabberKOSOnline, i18n ("Online"),         "actionOnline", SLOT(slotStatusOnline()) );
+    QAction( protocol()->JabberKOSChatty, i18n ("Free to Chat"),   "actionChatty", SLOT(slotStatusChatty()) );
+    QAction( protocol()->JabberKOSAway,   i18n ("Away"),           "actionAway",   SLOT(slotStatusAway()) );
+    QAction( protocol()->JabberKOSXA,     i18n ("Extended Away"),  "actionXA",     SLOT(slotStatusXA()) );
+    QAction( protocol()->JabberKOSDND,    i18n ("Do Not Disturb"), "actionDND",    SLOT(slotStatusDND()) );
+    QAction( protocol()->JabberKOSInvisible, i18n ("Invisible"),   "actionInvisible", SLOT(slotStatusInvisible()) );
 
-#undef KACTION
+#undef QAction
 
 	KActionMenu *actionSelectResource = new KActionMenu ( i18n ("Select Resource"), this );
 
@@ -235,8 +237,8 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 		{
 			if( i == activeItem )
 			{
-				KAction *tmp = new KAction( this );
-				tmp->setIcon( KIcon("dialog-ok") );
+				QAction *tmp = new QAction( this );
+                tmp->setIcon( QIcon::fromTheme(QStringLiteral("dialog-ok")) );
 				tmp->setText( str);
 				tmp->setObjectName( QString::number(i) );
 				connect(tmp, SIGNAL(triggered(bool)), SLOT(slotSelectResource()));
@@ -251,7 +253,7 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 				QIcon iconSet ( !i ?
 					protocol()->resourceToKOS ( account()->resourcePool()->bestResource ( mRosterItem.jid(), false ) ).iconFor ( account () ) : protocol()->resourceToKOS ( *availableResources.find(str) ).iconFor ( account () ));
 
-				KAction *tmp = new KAction(this);
+				QAction *tmp = new QAction(this);
 				tmp->setIcon( KIcon(iconSet) );
 				tmp->setText( str );
 				tmp->setObjectName( QString::number(i) );
@@ -267,17 +269,16 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 	actions->append( actionAuthorization );
 	actions->append( actionSetAvailability );
 	actions->append( actionSelectResource );
-	
-	
+
 #if 0
-	KAction *testAction = new KAction(i18n("Test action"), this);
+	QAction *testAction = new QAction(i18n("Test action"), this);
 	actionJingleAudioCall->setEnabled( true );
 	actionCollection->append( testAction );
 
-	KAction *actionJingleAudioCall = new KAction(i18n("Jingle Audio call"), this);
+	QAction *actionJingleAudioCall = new QAction(i18n("Jingle Audio call"), this);
 	connect(actionJingleAudioCall, SIGNAL(triggered(bool)), SLOT(slotJingleAudioCall()));
 	
-	KAction *actionJingleVideoCall = new KAction(i18n("Jingle Video call"), this);
+	QAction *actionJingleVideoCall = new QAction(i18n("Jingle Video call"), this);
 	connect(actionJingleVideoCall, SIGNAL(triggered(bool)), SLOT(slotJingleVideoCall()));
 
 	// Check if the current contact support jingle calls, also honor lock by default.
@@ -291,41 +292,41 @@ QList<KAction*> *JabberContact::customContextMenuActions ()
 
 	// temporary action collection, used to apply Kiosk policy to the actions
 	KActionCollection tempCollection((QObject*)0);
-	tempCollection.addAction(QLatin1String("jabberContactAuthorizationMenu"), actionAuthorization);
-	tempCollection.addAction(QLatin1String("contactSendAuth"), resendAuthAction);
-	tempCollection.addAction(QLatin1String("contactRequestAuth"), requestAuthAction);
-	tempCollection.addAction(QLatin1String("contactRemoveAuth"), removeAuthAction);
-	tempCollection.addAction(QLatin1String("jabberContactSetAvailabilityMenu"), actionSetAvailability);
-	tempCollection.addAction(QLatin1String("jabberContactSelectResource"), actionSelectResource);
+	tempCollection.addAction(QStringLiteral("jabberContactAuthorizationMenu"), actionAuthorization);
+	tempCollection.addAction(QStringLiteral("contactSendAuth"), resendAuthAction);
+	tempCollection.addAction(QStringLiteral("contactRequestAuth"), requestAuthAction);
+	tempCollection.addAction(QStringLiteral("contactRemoveAuth"), removeAuthAction);
+	tempCollection.addAction(QStringLiteral("jabberContactSetAvailabilityMenu"), actionSetAvailability);
+	tempCollection.addAction(QStringLiteral("jabberContactSelectResource"), actionSelectResource);
 	return actions;
 }
 
 void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 {
 	QString viewPlugin;
-	Kopete::Message *newMessage = 0L;
+	Kopete::Message *newMessage = nullptr;
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Received Message Type:" << message.type ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Received Message Type:" << message.type ();
 
 	// fetch message manager
 	JabberChatSession *mManager = manager ( message.from().resource (), Kopete::Contact::CanCreate );
 
 	// evaluate notifications
-	if ( message.type () != "error" )
+	if ( message.type () != QLatin1String("error") )
 	{
 		if (!message.invite().isEmpty())
 		{
 			QString room=message.invite();
 			QString originalBody=message.body().isEmpty() ? QString() :
-					i18n( "The original message is : <i>\" %1 \"</i><br />" , Qt::escape(message.body()));
+					i18n( "The original message is : <i>\" %1 \"</i><br />" , message.body().toHtmlEscaped());
 			QString mes=i18n("<qt><i>%1</i> has invited you to join the conference <b>%2</b><br />%3<br />"
 					"If you want to accept and join, just <b>enter your nickname</b> and press OK.<br />"
 							 "If you want to decline, press Cancel.</qt>",
 					message.from().full(), room , originalBody);
 			
 			bool ok=false;
-			QString futureNewNickName = KInputDialog::getText( i18n( "Invited to a conference - Jabber Plugin" ),
-					mes, QString() , &ok , (mManager ? dynamic_cast<QWidget*>(mManager->view(false)) : 0) );
+            QString futureNewNickName = QInputDialog::getText( (mManager ? dynamic_cast<QWidget*>(mManager->view(false)) : 0), i18n( "Invited to a conference - Jabber Plugin" ),
+                    mes,QLineEdit::Normal, QString() , &ok  );
 			if ( !ok || !account()->isConnected() || futureNewNickName.isEmpty() )
 				return;
 			
@@ -397,16 +398,16 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 		return;
 
 	// determine message type
-	if (message.type () == "chat")
-		viewPlugin = "kopete_chatwindow";
+	if (message.type () == QLatin1String("chat"))
+		viewPlugin = QStringLiteral("kopete_chatwindow");
 	else
-		viewPlugin = "kopete_emailwindow";
+		viewPlugin = QStringLiteral("kopete_emailwindow");
 
 	Kopete::ContactPtrList contactList;
 	contactList.append ( account()->myself () );
 
 	// check for errors
-	if ( message.type () == "error" )
+	if ( message.type () == QLatin1String("error") )
 	{
 		mManager->receivedMessageState( message.id().toUInt(), Kopete::Message::StateError );
 		newMessage = new Kopete::Message( this, contactList );
@@ -427,26 +428,26 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 		QString body = message.body ();
 		if( !message.xencrypted().isEmpty() )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Received encrypted message";
-			if (Kopete::PluginManager::self()->plugin("kopete_cryptography"))
+			qCDebug(JABBER_PROTOCOL_LOG) << "Received encrypted message";
+			if (Kopete::PluginManager::self()->plugin(QStringLiteral("kopete_cryptography")))
 			{
-				kDebug( JABBER_DEBUG_GLOBAL ) << "Kopete cryptography plugin loaded";
-				body = QString ("-----BEGIN PGP MESSAGE-----\n\n") + message.xencrypted () + QString ("\n-----END PGP MESSAGE-----\n");
+				qCDebug(JABBER_PROTOCOL_LOG) << "Kopete cryptography plugin loaded";
+				body = QStringLiteral ("-----BEGIN PGP MESSAGE-----\n\n") + message.xencrypted () + QStringLiteral ("\n-----END PGP MESSAGE-----\n");
 			}
 		}
 		else if( !message.xsigned().isEmpty() )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Received signed message";
-			if (Kopete::PluginManager::self()->plugin("kopete_cryptography"))
+			qCDebug(JABBER_PROTOCOL_LOG) << "Received signed message";
+			if (Kopete::PluginManager::self()->plugin(QStringLiteral("kopete_cryptography")))
 			{
-				kDebug( JABBER_DEBUG_GLOBAL ) << "Kopete cryptography plugin loaded";
-				body = QString ("-----BEGIN PGP MESSAGE-----\n\n") + message.xsigned () + QString ("\n-----END PGP MESSAGE-----\n");
+				qCDebug(JABBER_PROTOCOL_LOG) << "Kopete cryptography plugin loaded";
+				body = QStringLiteral ("-----BEGIN PGP MESSAGE-----\n\n") + message.xsigned () + QStringLiteral ("\n-----END PGP MESSAGE-----\n");
 			}
 		}
 
 		if( message.containsHTML() )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Received a xHTML message";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Received a xHTML message";
 			newMessage = new Kopete::Message ( this, contactList );
 			newMessage->setTimestamp( message.timeStamp() );
 			newMessage->setHtmlBody( message.html().toString() );
@@ -456,7 +457,7 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 		}
 		else if ( !body.isEmpty () )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Received a plain text message";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Received a plain text message";
 			newMessage = new Kopete::Message ( this, contactList );
 			newMessage->setTimestamp( message.timeStamp() );
 			newMessage->setPlainBody( body );
@@ -488,7 +489,7 @@ void JabberContact::handleIncomingMessage (const XMPP::Message & message)
 
 		Kopete::Message msg ( this, contactList );
 		msg.setTimestamp( message.timeStamp() );
-		msg.setHtmlBody( QString ( "<a href=\"%1\">%2</a>" ).arg ( xurl.url(), description ) );
+		msg.setHtmlBody( QStringLiteral ( "<a href=\"%1\">%2</a>" ).arg ( xurl.url(), description ) );
 		msg.setSubject( message.subject() );
 		msg.setDirection( Kopete::Message::Inbound );
 		msg.setRequestedPlugin( viewPlugin );
@@ -525,18 +526,17 @@ void JabberContact::slotCheckVCard ()
 		}
 	}
 
-
 	// avoid warning if key does not exist in configuration file
 	if ( cacheDateString.isNull () )
 		cacheDate = QDateTime::currentDateTime().addDays ( -2 );
 	else
 		cacheDate = QDateTime::fromString ( cacheDateString.value().toString (), Qt::ISODate );
 
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Cached vCard data for " << contactId () << " from " << cacheDate.toString ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Cached vCard data for " << contactId () << " from " << cacheDate.toString ();
 
 	if ( !mVCardUpdateInProgress && ( cacheDate.addDays ( 1 ) < QDateTime::currentDateTime () ) )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Scheduling update.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Scheduling update.";
 
 		mVCardUpdateInProgress = true;
 
@@ -573,7 +573,7 @@ void JabberContact::slotGetTimedVCard ()
 		}
 	}
 
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Requesting vCard for " << contactId () << " from update timer.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Requesting vCard for " << contactId () << " from update timer.";
 
 	mVCardUpdateInProgress = true;
 
@@ -637,7 +637,7 @@ void JabberContact::slotCheckLastActivity ( Kopete::Contact *, const Kopete::Onl
 	
 	if ( ( oldStatus.status () == Kopete::OnlineStatus::Connecting ) && newStatus.isDefinitelyOnline () )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Scheduling request for last activity for " << mRosterItem.jid().bare ();
+		qCDebug(JABBER_PROTOCOL_LOG) << "Scheduling request for last activity for " << mRosterItem.jid().bare ();
 
 		QTimer::singleShot ( account()->client()->getPenaltyTime () * 1000, this, SLOT (slotGetTimedLastActivity()) );
 	}
@@ -663,7 +663,7 @@ void JabberContact::slotGetTimedLastActivity ()
 
 	if ( account()->myself()->onlineStatus().isDefinitelyOnline () )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Requesting last activity from timer for " << mRosterItem.jid().bare ();
+		qCDebug(JABBER_PROTOCOL_LOG) << "Requesting last activity from timer for " << mRosterItem.jid().bare ();
 
 		JT_GetLastActivity *task = new JT_GetLastActivity ( account()->client()->rootTask () );
 		QObject::connect ( task, SIGNAL (finished()), this, SLOT (slotGotLastActivity()) );
@@ -800,8 +800,8 @@ void JabberContact::slotSendVCard()
 		vCard.setPhoto( ba );
 	}
 
-	vCard.setVersion("3.0");
-	vCard.setProdId("Kopete");
+	vCard.setVersion(QStringLiteral("3.0"));
+	vCard.setProdId(QStringLiteral("Kopete"));
 
 	XMPP::JT_VCard *task = new XMPP::JT_VCard (account()->client()->rootTask ());
 	// signal to ourselves when the vCard data arrived
@@ -816,8 +816,9 @@ void JabberContact::setPhoto( const QString &photoPath )
 	QString newPhotoPath = photoPath;
 	if(contactPhoto.width() > 96 || contactPhoto.height() > 96)
 	{
+        const QString jabberPhotoPath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "jabberphotos/";
 		// Save image to a new location if the image isn't the correct format.
-		QString newLocation( KStandardDirs::locateLocal( "appdata", "jabberphotos/"+ KUrl(photoPath).fileName().toLower() ) );
+        QString newLocation( jabberPhotoPath + QUrl(photoPath).fileName().toLower() ) ;
 	
 		// Scale and crop the picture.
 		contactPhoto = contactPhoto.scaled( 96, 96, Qt::KeepAspectRatio, Qt::SmoothTransformation );
@@ -836,7 +837,7 @@ void JabberContact::setPhoto( const QString &photoPath )
 	else if (contactPhoto.width() < 32 || contactPhoto.height() < 32)
 	{
 		// Save image to a new location if the image isn't the correct format.
-		QString newLocation( KStandardDirs::locateLocal( "appdata", "jabberphotos/"+ KUrl(photoPath).fileName().toLower() ) );
+		QString newLocation( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "jabberphotos/"+ QUrl(photoPath).fileName().toLower() ) ;
 	
 		// Scale and crop the picture.
 		contactPhoto = contactPhoto.scaled( 32, 32, Qt::KeepAspectRatio, Qt::SmoothTransformation );
@@ -855,7 +856,7 @@ void JabberContact::setPhoto( const QString &photoPath )
 	else if (contactPhoto.width() != contactPhoto.height())
 	{
 		// Save image to a new location if the image isn't the correct format.
-		QString newLocation( KStandardDirs::locateLocal( "appdata", "jabberphotos/"+ KUrl(photoPath).fileName().toLower() ) );
+		QString newLocation( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "jabberphotos/"+ QUrl(photoPath).fileName().toLower() ) ;
 
 		if(contactPhoto.width() < contactPhoto.height())
 			contactPhoto = contactPhoto.copy((contactPhoto.width()-contactPhoto.height())/2, 0, contactPhoto.height(), contactPhoto.height());
@@ -879,7 +880,7 @@ void JabberContact::slotSentVCard ()
 
 void JabberContact::slotChatSessionDeleted ( QObject *sender )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Message manager deleted, collecting the pieces...";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Message manager deleted, collecting the pieces...";
 
 	JabberChatSession *manager = static_cast<JabberChatSession *>(sender);
 
@@ -889,7 +890,7 @@ void JabberContact::slotChatSessionDeleted ( QObject *sender )
 
 JabberChatSession *JabberContact::manager ( Kopete::ContactPtrList chatMembers, Kopete::Contact::CanCreateFlags canCreate )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "called, canCreate: " << canCreate;
+	qCDebug(JABBER_PROTOCOL_LOG) << "called, canCreate: " << canCreate;
 
 	Kopete::ChatSession *_manager = Kopete::ChatSessionManager::self()->findChatSession ( account()->myself(), chatMembers, protocol() );
 	JabberChatSession *manager = dynamic_cast<JabberChatSession*>( _manager );
@@ -911,7 +912,7 @@ JabberChatSession *JabberContact::manager ( Kopete::ContactPtrList chatMembers,
 		if ( jid.resource().isEmpty () )
 			jid = jid.withResource ( account()->resourcePool()->lockedResource ( jid ).name () );
 
-		kDebug(JABBER_DEBUG_GLOBAL) << "No manager found, creating a new one with resource '" << jid.resource () << "'";
+		qCDebug(JABBER_PROTOCOL_LOG) << "No manager found, creating a new one with resource '" << jid.resource () << "'";
 
 		manager = new JabberChatSession ( protocol(), static_cast<JabberBaseContact *>(account()->myself()), chatMembers, jid.resource () );
 		connect ( manager, SIGNAL (destroyed(QObject*)), this, SLOT (slotChatSessionDeleted(QObject*)) );
@@ -924,7 +925,7 @@ JabberChatSession *JabberContact::manager ( Kopete::ContactPtrList chatMembers,
 
 Kopete::ChatSession *JabberContact::manager ( Kopete::Contact::CanCreateFlags canCreate )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "called, canCreate: " << canCreate;
+	qCDebug(JABBER_PROTOCOL_LOG) << "called, canCreate: " << canCreate;
 
 	Kopete::ContactPtrList chatMembers;
 	chatMembers.append ( this );
@@ -935,7 +936,7 @@ Kopete::ChatSession *JabberContact::manager ( Kopete::Contact::CanCreateFlags ca
 
 JabberChatSession *JabberContact::manager ( const QString &resource, Kopete::Contact::CanCreateFlags canCreate )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "called, canCreate: " << canCreate << ", Resource: '" << resource << "'";
+	qCDebug(JABBER_PROTOCOL_LOG) << "called, canCreate: " << canCreate << ", Resource: '" << resource << "'";
 
 	/*
 	 * First of all, see if we already have a manager matching
@@ -952,12 +953,12 @@ JabberChatSession *JabberContact::manager ( const QString &resource, Kopete::Con
 			if ( account()->mergeMessages () || mManager->resource().isEmpty () || ( mManager->resource () == resource ) )
 			{
 				// we found a matching manager, return this one
-				kDebug(JABBER_DEBUG_GLOBAL) << "Found an existing message manager for this resource.";
+				qCDebug(JABBER_PROTOCOL_LOG) << "Found an existing message manager for this resource.";
 				return mManager;
 			}
 		}
 
-		kDebug(JABBER_DEBUG_GLOBAL) << "No manager found for this resource, creating a new one.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "No manager found for this resource, creating a new one.";
 
 		/*
 		 * If we have come this far, we were either supposed to create
@@ -977,7 +978,7 @@ JabberChatSession *JabberContact::manager ( const QString &resource, Kopete::Con
 		return manager;
 	}
 
-	kDebug(JABBER_DEBUG_GLOBAL) << "Resource is empty, grabbing first available manager.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Resource is empty, grabbing first available manager.";
 
 	/*
 	 * The resource is empty, so just return first available manager.
@@ -988,7 +989,7 @@ JabberChatSession *JabberContact::manager ( const QString &resource, Kopete::Con
 
 void JabberContact::deleteContact ()
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Removing user " << contactId ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Removing user " << contactId ();
 
 	if ( !account()->isConnected () )
 	{
@@ -1009,7 +1010,7 @@ void JabberContact::deleteContact ()
 		int result = KMessageBox::questionYesNoCancel (Kopete::UI::Global::mainWidget(),
 		 				i18n ( "Do you also want to remove user %1's authorization to see your status?" , 
 						  mRosterItem.jid().bare () ), i18n ("Notification"),
-						KStandardGuiItem::del (), KGuiItem( i18n("Keep") ),KStandardGuiItem::cancel(), "JabberRemoveAuthorizationOnDelete" );
+						KStandardGuiItem::del (), KGuiItem( i18n("Keep") ),KStandardGuiItem::cancel(), QStringLiteral("JabberRemoveAuthorizationOnDelete") );
 		if(result == KMessageBox::Yes )
 			remove_from_roster = true;
 		else if( result == KMessageBox::Cancel)
@@ -1026,7 +1027,7 @@ void JabberContact::deleteContact ()
 	}
 	else
 	{
-		sendSubscription("unsubscribe");
+		sendSubscription(QStringLiteral("unsubscribe"));
 
 		XMPP::JT_Roster * rosterTask = new XMPP::JT_Roster ( account()->client()->rootTask () );
 		rosterTask->set ( mRosterItem.jid (), QString() , QStringList() );
@@ -1041,7 +1042,7 @@ void JabberContact::sync ( unsigned int )
 	if ( dontSync () || !account()->isConnected () || metaContact()->isTemporary () || metaContact() == Kopete::ContactList::self()->myself() )
 		return;
 	
-	kDebug ( JABBER_DEBUG_GLOBAL ) << contactId () /*<< " - " <<kdBacktrace()*/;
+	qCDebug(JABBER_PROTOCOL_LOG) << contactId () /*<< " - " <<kdBacktrace()*/;
 
 	if(!m_syncTimer)
 	{
@@ -1070,12 +1071,11 @@ void JabberContact::slotDelayedSync( )
 		return;
 	
 	bool changed=metaContact()->displayName() != mRosterItem.name();
-	
 
 	QStringList groups;
 	Kopete::GroupList groupList = metaContact ()->groups ();
 
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Synchronizing contact " << contactId ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Synchronizing contact " << contactId ();
 
 	foreach ( Kopete::Group * g, groupList )
 	{
@@ -1096,7 +1096,7 @@ void JabberContact::slotDelayedSync( )
 	
 	if(!changed)
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "contact has not changed,  abort sync";
+		qCDebug(JABBER_PROTOCOL_LOG) << "contact has not changed,  abort sync";
 		return;
 	}
 
@@ -1107,15 +1107,15 @@ void JabberContact::slotDelayedSync( )
 
 }
 
-void JabberContact::sendFile ( const KUrl &sourceURL, const QString &/*fileName*/, uint /*fileSize*/ )
+void JabberContact::sendFile ( const QUrl &sourceURL, const QString &/*fileName*/, uint /*fileSize*/ )
 {
 	QString filePath;
 
 	// if the file location is null, then get it from a file open dialog
 	if ( !sourceURL.isValid () )
-		filePath = KFileDialog::getOpenFileName( KUrl(), "*", 0L, i18n ( "Kopete File Transfer" ) );
+		filePath = QFileDialog::getOpenFileName(0L, i18n ( "Kopete File Transfer" ) ,  QString(), QStringLiteral("*"));
 	else
-		filePath = sourceURL.path(KUrl::RemoveTrailingSlash);
+		filePath = sourceURL.adjusted(QUrl::StripTrailingSlash).path();
 
 	QFile file ( filePath );
 
@@ -1127,31 +1127,30 @@ void JabberContact::sendFile ( const KUrl &sourceURL, const QString &/*fileName*
 
 }
 
-
 void JabberContact::slotSendAuth ()
 {
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "(Re)send auth " << contactId ();
+	qDebug (JABBER_PROTOCOL_LOG) << "(Re)send auth " << contactId ();
 
-	sendSubscription ("subscribed");
+	sendSubscription (QStringLiteral("subscribed"));
 
 }
 
 void JabberContact::slotRequestAuth ()
 {
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "(Re)request auth " << contactId ();
+	qDebug (JABBER_PROTOCOL_LOG) << "(Re)request auth " << contactId ();
 
-	sendSubscription ("subscribe");
+	sendSubscription (QStringLiteral("subscribe"));
 
 }
 
 void JabberContact::slotRemoveAuth ()
 {
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Remove auth " << contactId ();
+	qDebug (JABBER_PROTOCOL_LOG) << "Remove auth " << contactId ();
 
-	sendSubscription ("unsubscribed");
+	sendSubscription (QStringLiteral("unsubscribed"));
 
 }
 
@@ -1173,7 +1172,7 @@ void JabberContact::sendSubscription ( const QString& subType )
 
 void JabberContact::slotSelectResource ()
 {
-	int currentItem = QString ( static_cast<const KAction *>( sender() )->objectName () ).toUInt ();
+	int currentItem = QString ( static_cast<const QAction *>( sender() )->objectName () ).toUInt ();
 
 	/*
 	 * Warn the user if there is already an active chat window.
@@ -1182,8 +1181,7 @@ void JabberContact::slotSelectResource ()
 	 */
 	if ( manager ( Kopete::Contact::CannotCreate ) != 0 )
 	{
-		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
-										KMessageBox::Information,
+		KMessageBox::information ( Kopete::UI::Global::mainWidget (),
 										i18n ("You have preselected a resource for contact %1, "
 										"but you still have open chat windows for this contact. "
 										"The preselected resource will only apply to newly opened "
@@ -1193,16 +1191,16 @@ void JabberContact::slotSelectResource ()
 
 	if (currentItem == 0)
 	{
-		kDebug (JABBER_DEBUG_GLOBAL) << "Removing active resource, trusting bestResource().";
+		qDebug (JABBER_PROTOCOL_LOG) << "Removing active resource, trusting bestResource().";
 
 		account()->resourcePool()->removeLock ( rosterItem().jid() );
 	}
 	else
 	{
 		// use iconText() instead of text(), because we need stripped value without '&'
-		QString selectedResource = static_cast<const KAction *>(sender())->iconText();
+		QString selectedResource = static_cast<const QAction *>(sender())->iconText();
 
-		kDebug (JABBER_DEBUG_GLOBAL) << "Moving to resource " << selectedResource;
+		qDebug (JABBER_PROTOCOL_LOG) << "Moving to resource " << selectedResource;
 
 		account()->resourcePool()->lockToResource ( rosterItem().jid() , XMPP::Resource ( selectedResource ) );
 	}
@@ -1231,12 +1229,11 @@ void JabberContact::sendPresence ( const XMPP::Status status )
 
 }
 
-
 void JabberContact::slotStatusOnline ()
 {
 
 	XMPP::Status status;
-	status.setShow("");
+	status.setShow(QLatin1String(""));
 
 	sendPresence ( status );
 
@@ -1246,7 +1243,7 @@ void JabberContact::slotStatusChatty ()
 {
 
 	XMPP::Status status;
-	status.setShow ("chat");
+	status.setShow (QStringLiteral("chat"));
 
 	sendPresence ( status );
 
@@ -1256,7 +1253,7 @@ void JabberContact::slotStatusAway ()
 {
 
 	XMPP::Status status;
-	status.setShow ("away");
+	status.setShow (QStringLiteral("away"));
 
 	sendPresence ( status );
 
@@ -1266,7 +1263,7 @@ void JabberContact::slotStatusXA ()
 {
 
 	XMPP::Status status;
-	status.setShow ("xa");
+	status.setShow (QStringLiteral("xa"));
 
 	sendPresence ( status );
 
@@ -1276,11 +1273,10 @@ void JabberContact::slotStatusDND ()
 {
 
 	XMPP::Status status;
-	status.setShow ("dnd");
+	status.setShow (QStringLiteral("dnd"));
 
 	sendPresence ( status );
 
-
 }
 
 void JabberContact::slotStatusInvisible ()
@@ -1334,7 +1330,7 @@ void JabberContact::slotDiscoFinished( )
 		for ( it = identities.begin(); it != identities.end(); ++it )
 		{
 			XMPP::DiscoItem::Identity ident=*it;
-			if(ident.category == "gateway")
+			if(ident.category == QLatin1String("gateway"))
 			{
 				is_transport=true;
 				tr_type=ident.type;
@@ -1342,11 +1338,11 @@ void JabberContact::slotDiscoFinished( )
 		
 				break;  //(we currently only support gateway)
 			}
-			else if (ident.category == "service")
+			else if (ident.category == QLatin1String("service"))
 			{
 				//The ApaSMSAgent is reporting itself as service (instead of gateway) which is broken.
 				//we anyway support it.  See bug  127811
-				if(ident.type == "sms")
+				if(ident.type == QLatin1String("sms"))
 				{
 					is_transport=true;
 					tr_type=ident.type;
@@ -1363,11 +1359,11 @@ void JabberContact::slotDiscoFinished( )
 		JabberAccount *parentAccount=account();
 		Kopete::OnlineStatus status=onlineStatus();
 		
-		kDebug(JABBER_DEBUG_GLOBAL) << ri.jid().full() << " is not a contact but a gateway   - " << this;
+		qCDebug(JABBER_PROTOCOL_LOG) << ri.jid().full() << " is not a contact but a gateway   - " << this;
 		
 		if( Kopete::AccountManager::self()->findAccount( protocol()->pluginId() , account()->accountId() + '/' + ri.jid().bare() ) )
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "oops, transport already exists, abort operation ";
+			qCDebug(JABBER_PROTOCOL_LOG) << "oops, transport already exists, abort operation ";
 			return;
 		}
 		
@@ -1411,7 +1407,7 @@ void JabberContact::startJingleAudioCall()
 
 void JabberContact::startJingleVideoCall()
 {
-	kDebug() << "Start a Jingle Session";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Start a Jingle Session";
 
 	//JingleCallsManager should manage messages itself.
 	/*XMPP::Jid jid = rosterItem().jid();
@@ -1449,4 +1445,3 @@ void JabberContact::makeLibjingleCallAction()
 
 #endif
 
-#include "jabbercontact.moc"
