@@ -1,4 +1,4 @@
- /*
+/*
   * jabberformlineedit.h
   *
   * Copyright (c) 2002-2003 by Till Gerken <till@tantalo.net>
@@ -19,7 +19,7 @@
 #define JABBERFORMLINEEDIT_H
 
 #include <qwidget.h>
-#include <klineedit.h>
+#include <QLineEdit>
 
 #include "xmpp_tasks.h"
 
@@ -27,19 +27,17 @@
   *@author Till Gerken <till@tantalo.net>
   */
 
-class JabberFormLineEdit:public KLineEdit
+class JabberFormLineEdit : public QLineEdit
 {
+    Q_OBJECT public:
+    JabberFormLineEdit (const int type, const QString &realName, const QString &value, QWidget *parent = nullptr);
+    ~JabberFormLineEdit ();
 
-  Q_OBJECT public:
-	  JabberFormLineEdit (const int type, const QString & realName, const QString & value, QWidget * parent = 0);
-	 ~JabberFormLineEdit ();
-
-	public slots:void slotGatherData (XMPP::Form & form);
-
-  private:
-	int fieldType;
-	QString fieldName;
+public Q_SLOTS: void slotGatherData(XMPP::Form &form);
 
+private:
+    int fieldType;
+    QString fieldName;
 };
 
 #endif
