@@ -29,6 +29,11 @@
 
 #include "irisnetglobal.h"
 
+// it seems visual studio defines it somewhere
+#ifdef max
+# undef max
+#endif
+
 namespace XMPP {
 
 class NameManager;
@@ -418,7 +423,7 @@ public:
 	/**
 	   \brief Constructs a new resolver object with the given \a parent
 	*/
-	NameResolver(QObject *parent = 0);
+	NameResolver(QObject *parent = nullptr);
 
 	/**
 	   \brief Destroys the resolver object
@@ -520,7 +525,7 @@ public:
 		ErrorNoWide
 	};
 
-	ServiceBrowser(QObject *parent = 0);
+	ServiceBrowser(QObject *parent = nullptr);
 	~ServiceBrowser();
 
 	void start(const QString &type, const QString &domain = "local");
@@ -586,7 +591,7 @@ public:
 	 * Create a new ServiceResolver.
 	 * This resolver can be used for multiple lookups in a row, but not concurrently!
 	 */
-	ServiceResolver(QObject *parent = 0);
+	ServiceResolver(QObject *parent = nullptr);
 	~ServiceResolver();
 
 	Protocol protocol() const; //!< IP protocol to use, defaults to IPv6_IPv4
@@ -672,7 +677,7 @@ public:
 		ErrorNoLocal   // unable to setup multicast dns
 	};
 
-	ServiceLocalPublisher(QObject *parent = 0);
+	ServiceLocalPublisher(QObject *parent = nullptr);
 	~ServiceLocalPublisher();
 
 	void publish(const QString &instance, const QString &type, int port, const QMap<QString,QByteArray> &attributes);
