@@ -23,13 +23,52 @@
 
 #include <QList>
 #include <QString>
+#include <QStringList>
 #include <QDateTime>
+#include <QCryptographicHash>
 
 #include "xmpp_muc.h"
 #include "xmpp_bitsofbinary.h"
 
 namespace XMPP
 {
+	class DiscoItem;
+	class CapsSpec
+	{
+		public:
+			typedef QMap<QString,QCryptographicHash::Algorithm> CryptoMap;
+			static const QCryptographicHash::Algorithm invalidAlgo = (QCryptographicHash::Algorithm)255;
+
+			CapsSpec();
+			CapsSpec(const QString& node, QCryptographicHash::Algorithm hashAlgo, const QString& ver = QString::null);
+			CapsSpec(const DiscoItem &disco, QCryptographicHash::Algorithm hashAlgo = QCryptographicHash::Sha1);
+
+			bool isValid() const;
+			const QString& node() const;
+			const QString& version() const;
+			QCryptographicHash::Algorithm hashAlgorithm() const;
+			inline const QStringList &ext() const { return ext_; }
+			QString flatten() const;
+
+			void resetVersion();
+
+			bool operator==(const CapsSpec&) const;
+			bool operator!=(const CapsSpec&) const;
+			bool operator<(const CapsSpec&) const;
+
+			QDomElement toXml(QDomDocument *doc) const;
+			static CapsSpec fromXml(const QDomElement &e);
+
+			static CryptoMap &cryptoMap();
+
+		private:
+			QString node_, ver_;
+			QCryptographicHash::Algorithm hashAlgo_;
+			QStringList ext_;
+	};
+
+	class StatusPrivate;
+
 	class Status
 	{
 	public:
@@ -37,6 +76,8 @@ namespace XMPP
 
 		Status(const QString &show=QString(), const QString &status=QString(), int priority=0, bool available=true);
 		Status(Type type, const QString& status=QString(), int priority=0);
+		Status(const Status &);
+		Status &operator=(const Status &);
 		~Status();
 
 		int priority() const;
@@ -55,10 +96,7 @@ namespace XMPP
 
 		const QString & xsigned() const;
 		const QString & songTitle() const;
-		const QString & capsNode() const;
-		const QString & capsVersion() const;
-		const QString & capsHashAlgorithm() const;
-		const QString & capsExt() const;
+		const CapsSpec & caps() const;
 
 		bool isMUC() const;
 		bool hasMUCItem() const;
@@ -73,6 +111,8 @@ namespace XMPP
 		int mucHistorySeconds() const;
 		const QDateTime & mucHistorySince() const;
 
+		static Type txt2type(const QString& stat);
+
 		void setPriority(int);
 		void setType(Type);
 		void setType(QString);
@@ -83,10 +123,7 @@ namespace XMPP
 		void setIsAvailable(bool);
 		void setIsInvisible(bool);
 		void setError(int, const QString &);
-		void setCapsNode(const QString&);
-		void setCapsVersion(const QString&);
-		void setCapsHashAlgorithm(const QString&);
-		void setCapsExt(const QString&);
+		void setCaps(const CapsSpec&);
 
 		void setMUC();
 		void setMUCItem(const MUCItem&);
@@ -108,31 +145,7 @@ namespace XMPP
 		QList<BoBData> bobDataList() const;
 
 	private:
-		int v_priority;
-		QString v_show, v_status, v_key;
-		QDateTime v_timeStamp;
-		bool v_isAvailable;
-		bool v_isInvisible;
-		QString v_photoHash;
-		bool v_hasPhotoHash;
-
-		QString v_xsigned;
-		// gabber song extension
-		QString v_songTitle;
-		QString v_capsNode, v_capsVersion, v_capsHashAlgorithm, v_capsExt;
-		QList<BoBData> v_bobDataList;
-
-		// MUC
-		bool v_isMUC, v_hasMUCItem, v_hasMUCDestroy;
-		MUCItem v_mucItem;
-		MUCDestroy v_mucDestroy;
-		QList<int> v_mucStatuses;
-		QString v_mucPassword;
-		int v_mucHistoryMaxChars, v_mucHistoryMaxStanzas, v_mucHistorySeconds;
-		QDateTime v_mucHistorySince;
-
-		int ecode;
-		QString estr;
+		QSharedDataPointer<StatusPrivate> d;
 	};
 
 }
