@@ -26,10 +26,10 @@
 #include <QByteArray>
 #include <QPointer>
 #include <QTextCodec>
-#include <QtNetwork/QSslSocket>
+#include <QSslSocket>
 
-#include <kdebug.h> //for kDebug()
-#include <klocale.h>
+#include <kdebug.h> //for qDebug()
+#include <KLocalizedString>
 
 #include "filetransfertask.h"
 #include "buddyicontask.h"
@@ -76,17 +76,16 @@
 #include "chatroomtask.h"
 #include "chatroomhandler.h"
 
-
 namespace
 {
 	class DefaultCodecProvider : public Client::CodecProvider
 	{
 	public:
-		virtual QTextCodec* codecForContact( const QString& ) const
+		QTextCodec* codecForContact( const QString& ) const Q_DECL_OVERRIDE
 		{
 			return QTextCodec::codecForMib( 4 );
 		}
-		virtual QTextCodec* codecForAccount() const
+		QTextCodec* codecForAccount() const Q_DECL_OVERRIDE
 		{
 			return QTextCodec::codecForMib( 4 );
 		}
@@ -174,7 +173,7 @@ public:
 Client::Client( QObject* parent )
 :QObject( parent )
 {
-	setObjectName( "oscarclient" );
+	setObjectName( QStringLiteral("oscarclient") );
 
 	d = new ClientPrivate;
 	d->tzoffset = 0;
@@ -189,20 +188,20 @@ Client::Client( QObject* parent )
 	d->status.sent = false;
 	d->ssiManager = new ContactManager( this );
 	d->settings = new Oscar::Settings();
-	d->errorTask = 0L;
-	d->onlineNotifier = 0L;
-	d->ownStatusTask = 0L;
-	d->messageReceiverTask = 0L;
-	d->messageAckTask = 0L;
-	d->ssiAuthTask = 0L;
-	d->icqInfoTask = 0L;
-	d->icqTlvInfoTask = 0L;
-	d->userInfoTask = 0L;
+	d->errorTask = nullptr;
+	d->onlineNotifier = nullptr;
+	d->ownStatusTask = nullptr;
+	d->messageReceiverTask = nullptr;
+	d->messageAckTask = nullptr;
+	d->ssiAuthTask = nullptr;
+	d->icqInfoTask = nullptr;
+	d->icqTlvInfoTask = nullptr;
+	d->userInfoTask = nullptr;
 	d->stage = ClientPrivate::StageOne;
-	d->loginTask = 0L;
-	d->loginTaskTwo = 0L;
-	d->typingNotifyTask = 0L;
-	d->ssiModifyTask = 0L;
+	d->loginTask = nullptr;
+	d->loginTaskTwo = nullptr;
+	d->typingNotifyTask = nullptr;
+	d->ssiModifyTask = nullptr;
 	d->awayMsgRequestTimer = new QTimer();
 	d->codecProvider = &defaultCodecProvider;
 
@@ -604,7 +603,7 @@ void Client::notifySocketError( int errCode, const QString& msg )
 
 void Client::sendMessage( const Oscar::Message& msg, bool isAuto)
 {
-    Connection* c = 0L;
+    Connection* c = nullptr;
     if ( msg.channel() == 0x0003 )
     {
         c = d->connections.connectionForChatRoom( msg.exchange(), msg.chatRoom() );
@@ -658,9 +657,9 @@ void Client::receivedMessage( const Oscar::Message& msg )
 					using namespace Xtraz;
 					XtrazNotify xNotify;
 					xNotify.handle( msg.plugin() );
-					if ( xNotify.type() == XtrazNotify::Request && xNotify.pluginId() == "srvMng" )
+					if ( xNotify.type() == XtrazNotify::Request && xNotify.pluginId() == QLatin1String("srvMng") )
 					{
-						if ( xNotify.findService( "cAwaySrv" ) )
+						if ( xNotify.findService( QStringLiteral("cAwaySrv") ) )
 						{
 							XtrazNotify xNotifyResponse;
 							xNotifyResponse.setSenderUni( userId() );
@@ -718,7 +717,7 @@ void Client::receivedMessage( const Oscar::Message& msg )
 					xNotify.handle( msg.plugin() );
 					if ( xNotify.type() == XtrazNotify::Response )
 					{
-						const Xtraz::XAwayService* service = dynamic_cast<const XAwayService*>(xNotify.findService( "cAwaySrv" ));
+						const Xtraz::XAwayService* service = dynamic_cast<const XAwayService*>(xNotify.findService( QStringLiteral("cAwaySrv") ));
 						if ( service )
 							emit receivedXStatusMessage( service->senderId(), service->iconIndex(),
 							                             service->description(), service->message() );
@@ -1253,7 +1252,7 @@ void Client::requestICQAwayMessage( const QString& contact, ICQStatus contactSta
 			break;
 		default:
 			// may be a good way to deal with possible error and lack of online status message?
-			emit receivedAwayMessage( contact, "Sorry, this protocol does not support this type of status message" );
+			emit receivedAwayMessage( contact, QStringLiteral("Sorry, this protocol does not support this type of status message") );
 			return;
 		}
 
@@ -1293,7 +1292,7 @@ void Client::requestICQAwayMessage( const QString& contact, ICQStatus contactSta
 			break;
 		default:
 			// may be a good way to deal with possible error and lack of online status message?
-			emit receivedAwayMessage( contact, "Sorry, this protocol does not support this type of status message" );
+			emit receivedAwayMessage( contact, QStringLiteral("Sorry, this protocol does not support this type of status message") );
 			return;
 		}
 	}
@@ -1553,7 +1552,7 @@ void Client::haveServerForRedirect( const QString& host, const QByteArray& cooki
 	if ( colonPos != -1 )
 	{
 		realHost = host.left( colonPos );
-		realPort = host.right(4).toUInt(); //we only need 4 bytes
+		realPort = host.rightRef(4).toUInt(); //we only need 4 bytes
 	}
 	else
 	{
@@ -1647,7 +1646,6 @@ void Client::checkRedirectionQueue( Oscar::WORD family )
 	}
 }
 
-
 void Client::requestChatNavLimits()
 {
 	Connection* c = d->connections.connectionForFamily( 0x000D );
@@ -1856,5 +1854,3 @@ void Client::gotFileMessage( int type, const QString from, const QByteArray cook
 
 }
 
-#include "client.moc"
-//kate: tab-width 4; indent-mode csands; space-indent off; replace-tabs off;
