@@ -22,18 +22,18 @@
 
 #include "filetransfertask.h"
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QTextCodec>
-#include <QtNetwork/QHostAddress>
-#include <QtNetwork/QTcpServer>
-#include <QtNetwork/QTcpSocket>
-#include <QtXml/QDomDocument>
+#include <QFileInfo>
+#include <QTextCodec>
+#include <QHostAddress>
+#include <QTcpServer>
+#include <QTcpSocket>
+#include <QDomDocument>
 
 #include <ksocketfactory.h>
 #include <krandom.h>
 #include <kio/global.h>
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kdebug.h>
 
 #include "buffer.h"
@@ -605,7 +605,6 @@ void FileTransferTask::doCancel()
 	setSuccess( true );
 }
 
-
 void FileTransferTask::doAccept( const QString &localDirecotry )
 {
 	kDebug(OSCAR_RAW_DEBUG) << "directory: " << localDirecotry;
@@ -658,7 +657,7 @@ void FileTransferTask::doConnect()
 
 	QString host;
 	if ( m_proxyRequester )
-		host = "ars.oscar.aol.com";
+		host = QStringLiteral("ars.oscar.aol.com");
 	else
 	{
 		if ( m_ip.length() != 4 || ! m_port )
@@ -891,13 +890,10 @@ QString FileTransferTask::parseDescription( const QByteArray &description ) cons
 		return QString::fromUtf8( description );
 	}
 	
-	QDomNodeList descList = xmlDocument.elementsByTagName( "DESC" );
+	QDomNodeList descList = xmlDocument.elementsByTagName( QStringLiteral("DESC") );
 	if ( descList.count() == 1 )
 		return descList.at( 0 ).toElement().text();
 	else
 		return QString::fromUtf8( description );
 }
 
-#include "filetransfertask.moc"
-//kate: space-indent off; tab-width 4; indent-mode csands;
-
