@@ -20,7 +20,7 @@
 #define OSCARLISTNONSERVERCONTACTS_H
 
 #include <kdialog.h>
-#include "kopete_export.h"
+#include "oscar_export.h"
 
 namespace Ui { class OscarListContactsBase; }
 class QStringList;
@@ -38,9 +38,9 @@ public:
     bool onlyShowOnce();
 
 protected:
-    virtual void slotButtonClicked( int buttonCode );
+    void slotButtonClicked( int buttonCode ) Q_DECL_OVERRIDE;
 
-signals:
+Q_SIGNALS:
     void closing();
 
 private:
