@@ -14,18 +14,17 @@
     *************************************************************************
 */
 
-
 #include "qqaccount.h"
 
 #include <QTextCodec>
 #include <QDateTime>
 
-#include <kaction.h>
+#include <qaction.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kactionmenu.h>
-#include <kmenu.h>
-#include <kicon.h>
+#include <QMenu>
+#include <QIcon>
 #include <kconfiggroup.h>
 
 #include "kopetemetacontact.h"
@@ -37,11 +36,10 @@
 #include "qqprotocol.h"
 #include "qqchatsession.h"
 
-
 QQAccount::QQAccount( QQProtocol *parent, const QString& accountID )
 : Kopete::PasswordedAccount ( parent, accountID )
 {
-	m_notifySocket = 0L;
+	m_notifySocket = nullptr;
 	m_connectstatus = QQProtocol::protocol()->Offline;
 	m_newContactList=false;
 	m_codec = QTextCodec::codecForName("GB18030");
@@ -76,7 +74,7 @@ void QQAccount::connect( const Kopete::OnlineStatus& /* initialStatus */ )
 		return;
 	}
 	/* Hard-coded password for debug only */
-	m_password = "qqsucks";
+	m_password = QStringLiteral("qqsucks");
 	createNotificationServer(serverName(), serverPort());
 }
 
@@ -88,7 +86,7 @@ void QQAccount::createNotificationServer( const QString &host, uint port )
 		// from the old socket thinking they are from the new one
 		QObject::disconnect( m_notifySocket , 0, this, 0 );
 		m_notifySocket->deleteLater(); //be sure it will be deleted
-		m_notifySocket = 0L;
+		m_notifySocket = nullptr;
 	}
 
 	myself()->setOnlineStatus( QQProtocol::protocol()->CNT );
@@ -131,10 +129,8 @@ void QQAccount::fillActionMenu( KActionMenu *actionMenu )
 
 	actionMenu->addSeparator();
 
-	KAction *action;
-
-	action = new KAction (KIcon("qq_showvideo"), i18n ("Show my own video..."), actionMenu );
-        action->setObjectName("actionShowVideo");
+    QAction *action = new QAction (QIcon::fromTheme(QStringLiteral("qq_showvideo")), i18n ("Show my own video..."), actionMenu );
+        action->setObjectName(QStringLiteral("actionShowVideo"));
 	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotShowVideo()) );
 	actionMenu->addAction(action);
 	action->setEnabled( isConnected() );
@@ -164,12 +160,11 @@ void QQAccount::setStatusMessage(const Kopete::StatusMessage& statusMessage)
 	setOnlineStatus( myself()->onlineStatus(), statusMessage, Kopete::Account::KeepSpecialFlags );
 }
 
-
 bool QQAccount::createContact(const QString& contactId, Kopete::MetaContact* parentContact)
 {
 	kDebug( 14140 ) ;
 	QQContact* newContact = new QQContact( this, contactId, parentContact );
-	return newContact != 0L;
+	return newContact != nullptr;
 
 }
 
@@ -188,7 +183,6 @@ QQChatSession * QQAccount::findChatSessionByGuid( const QString& guid )
 	return chatSession;
 }
 
-
 QQChatSession * QQAccount::chatSession( Kopete::ContactPtrList others, const QString& guid, Kopete::Contact::CanCreateFlags canCreate )
 {
 	QQChatSession * chatSession = 0;
@@ -239,7 +233,6 @@ QQChatSession * QQAccount::chatSession( Kopete::ContactPtrList others, const QSt
 	return chatSession;
 }
 
-
 void QQAccount::sendMessage(const QString& guid, Kopete::Message& message )
 {
 	kDebug(14140) << "Sending the message to " << guid;
@@ -276,7 +269,6 @@ void QQAccount::slotStatusChanged( const Kopete::OnlineStatus &status )
 		// m_notifySocket->sendContactList();
 		// Fetch the relation of contact <--> group
 
-
 	}
 }
 
@@ -319,7 +311,6 @@ void QQAccount::slotShowVideo ()
 	updateContactStatus();
 }
 
-
 void QQAccount::slotNewContactList()
 {
 	kDebug ( 14210 ) ;
@@ -338,9 +329,9 @@ void QQAccount::slotNewContactList()
 			c->setAllowed( false );
 			c->setReversed( false );
 			c->setDeleted( true );
-			c->setInfo( "PHH", QString() );
-			c->setInfo( "PHW", QString() );
-			c->setInfo( "PHM", QString() );
+			c->setInfo( QStringLiteral("PHH"), QString() );
+			c->setInfo( QStringLiteral("PHW"), QString() );
+			c->setInfo( QStringLiteral("PHM"), QString() );
 			// c->removeProperty( QQProtocol::protocol()->propGuid );
 		}
 		m_newContactList=true;
@@ -391,7 +382,6 @@ void QQAccount::slotContactListed( const Eva::ContactInfo& ci )
 	return ;
 }
 
-
 void QQAccount::slotContactStatusChanged(const Eva::ContactStatus& cs)
 {
 	kDebug(14210) << "qqId = " << cs.qqId << " from " << cs.ip << ":" << cs.port << " status = " << cs.status;
@@ -402,7 +392,6 @@ void QQAccount::slotContactStatusChanged(const Eva::ContactStatus& cs)
 		c->setOnlineStatus( fromEvaStatus(cs.status) );
 }
 
-
 Kopete::OnlineStatus QQAccount::fromEvaStatus( char es )
 {
 	Kopete::OnlineStatus status;
@@ -460,7 +449,6 @@ void QQAccount::slotMessageReceived( const Eva::MessageHeader& header, const Eva
 	sess->appendMessage( newMessage );
 }
 
-
 void QQAccount::slotContactDetailReceived( const QString& id, const QMap<const char*, QByteArray>& map)
 {
 	kDebug(14140) << "contact:" << id;
@@ -482,4 +470,3 @@ void QQAccount::getVCard( QQContact* contact )
 	return ;
 }
 
-#include "qqaccount.moc"
