@@ -19,12 +19,10 @@
 #include "qqeditaccountwidget.h"
 
 #include <qcheckbox.h>
-#include <q3groupbox.h>
 #include <qimage.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
-#include <q3listbox.h>
 #include <qpushbutton.h>
 #include <qregexp.h>
 #include <qspinbox.h>
@@ -32,10 +30,9 @@
 #include <QVBoxLayout>
 #include <QLatin1String>
 
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kmessagebox.h>
-#include <kstandarddirs.h>
+
 #include <kio/netaccess.h>
 #include <kdebug.h>
 #include <ktoolinvocation.h>
@@ -54,6 +51,7 @@
 #include "qqnotifysocket.h"
 #include "qqprotocol.h"
 #include "dlgqqvcard.h"
+#include <kmessagebox_queued.h>
 
 // TODO: This was using KAutoConfig before, use KConfigXT instead.
 class QQEditAccountWidgetPrivate
@@ -93,7 +91,7 @@ QQEditAccountWidget::QQEditAccountWidget( QQProtocol *proto, Kopete::Account *ac
 		QQAccount *m_account = static_cast<QQAccount*>( account );
 		d->ui->m_serverName->setText( m_account->serverName() );
 		d->ui->m_serverPort->setValue( m_account->serverPort() );
-		if ( ( m_account->serverName() != "tcpconn.tencent.com" ) || ( m_account->serverPort() != 80) ) {
+		if ( ( m_account->serverName() != QLatin1String("tcpconn.tencent.com") ) || ( m_account->serverPort() != 80) ) {
 			d->ui->optionOverrideServer->setChecked( true );
 			d->ui->m_serverName->setEnabled(true);
 			d->ui->m_serverPort->setEnabled(true);
@@ -104,6 +102,9 @@ QQEditAccountWidget::QQEditAccountWidget( QQProtocol *proto, Kopete::Account *ac
 	QWidget::setTabOrder( d->ui->m_login, d->ui->m_password->mRemembered );
 	QWidget::setTabOrder( d->ui->m_password->mRemembered, d->ui->m_password->mPassword );
 	QWidget::setTabOrder( d->ui->m_password->mPassword, d->ui->m_autologin );
+    if (parent && parent->layout()) {
+        parent->layout()->addWidget(this);
+    }
 }
 
 QQEditAccountWidget::~QQEditAccountWidget()
@@ -175,10 +176,6 @@ bool QQEditAccountWidget::validateData()
 
 void QQEditAccountWidget::slotOpenRegister()
 {
-	KToolInvocation::invokeBrowser( "http://freereg.qq.com/"  );
+	KToolInvocation::invokeBrowser( QStringLiteral("http://freereg.qq.com/")  );
 }
 
-#include "qqeditaccountwidget.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
-
