@@ -18,44 +18,43 @@
 #include <qlayout.h>
 #include <kdebug.h>
 
-SMSService::SMSService(Kopete::Account* account)
-	: QObject(), m_account(account), m_layout(NULL), m_parent(NULL)
+SMSService::SMSService(Kopete::Account *account)
+    : QObject()
+    , m_account(account)
+    , m_layout(NULL)
+    , m_parent(NULL)
 {
 }
 
 SMSService::~SMSService()
 {
-
 }
 
-void SMSService::setAccount(Kopete::Account* account)
+void SMSService::setAccount(Kopete::Account *account)
 {
-	if(!m_account)
-		m_account = account;
-	if(account)
-		savePreferences();
+    if (!m_account) {
+        m_account = account;
+    }
+    if (account) {
+        savePreferences();
+    }
 }
 
 // The Default impl simply flips a signal back
 void SMSService::connect()
 {
-	emit connected();
+    emit connected();
 }
 
 // The Default impl simply flips a signal back
 void SMSService::disconnect()
 {
-	emit disconnected();
+    emit disconnected();
 }
 
 /*
  * Local variables:
  * c-indentation-style: k&r
- * c-basic-offset: 8
  * indent-tabs-mode: t
  * End:
  */
-// vim: set noet ts=4 sts=4 sw=4:
-
-
-#include "smsservice.moc"
