@@ -35,6 +35,9 @@ TestbedEditAccountWidget::TestbedEditAccountWidget( QWidget* parent, Kopete::Acc
 	m_preferencesWidget = new Ui::TestbedAccountPreferences();
 	m_preferencesWidget->setupUi( widget );
 	layout->addWidget( widget );
+    if (parent && parent->layout()) {
+        parent->layout()->addWidget(this);
+    }
 }
 
 TestbedEditAccountWidget::~TestbedEditAccountWidget()
@@ -46,7 +49,7 @@ Kopete::Account* TestbedEditAccountWidget::apply()
 {
 	QString accountName;
 	if ( m_preferencesWidget->m_acctName->text().isEmpty() )
-		accountName = "Testbed Account";
+		accountName = QStringLiteral("Testbed Account");
 	else
 		accountName = m_preferencesWidget->m_acctName->text();
 	
@@ -65,4 +68,3 @@ bool TestbedEditAccountWidget::validateData()
 	return true;
 }
 
-#include "testbededitaccountwidget.moc"
